@@ -132,15 +132,15 @@ void BackEnd::init_SWORD(int gsType) {
 					it != display_mgr->Modules.end(); it++) {
 			display_mod = (*it).second;
 			if (!strcmp(display_mod->Type(), TEXT_MODS)) {
-#ifdef USE_GTKMOZEMBED
+/*#ifdef USE_GTKMOZEMBED
 				display_mod->setDisplay(textDisplay);
 #else
 				const char *direction = display_mod->getConfigEntry("Direction");
 				if(direction && !strcmp(direction,"RtoL" ))
 					display_mod->setDisplay(RTOLDisplay);
-				else
+				else*/
 					display_mod->setDisplay(textDisplay);
-#endif
+//#endif
 			}
 			if (!strcmp(display_mod->Type(), COMM_MODS)) {
 				display_mod->setDisplay(commDisplay);
@@ -247,7 +247,8 @@ char *BackEnd::set_sword_locale(const char *sys_locale) {
 	if(sw_locale) {
 		OLD_CODESET = (char*)sw_locale->getEncoding();
 	} else {
-		OLD_CODESET = "iso8859-1";
+//		OLD_CODESET = "iso8859-1";
+		OLD_CODESET = "UTF-8";
 	}
 	return retval;
 }
@@ -385,6 +386,7 @@ char *BackEnd::get_render_text(const char *module_name, const char *key) {
 				     error);
 		mod = (*it).second;
 		mod->setKey(mykey);
+		//g_message("mykey: %s", mykey);
 		g_free(mykey);
 		return strdup((char *) mod->RenderText());
 	}
@@ -874,7 +876,7 @@ int BackEnd::set_module_key(const char *module_name, const char *key) {
        	 	gsize bytes_written;
         	GError *error = NULL;
 #ifdef DEBUG 
-		g_message(f_message,734,"key",key);
+		g_message(f_message,878,"key",key);
 #endif
 		mykey = g_convert(key,
                              -1,
@@ -889,7 +891,7 @@ int BackEnd::set_module_key(const char *module_name, const char *key) {
 		}
 		display_mod->setKey(mykey);
 #ifdef DEBUG 
-		g_message(f_message,743,"mykey",mykey);
+		g_message(f_message,893,"mykey",mykey);
 #endif
 		g_free(mykey);
 		return 1;
@@ -955,7 +957,16 @@ char *BackEnd::get_key_form_offset(unsigned long offset) {
         return retval;
 }
 
-
+unsigned long BackEnd::treekey_set_key(char * key) {
+	if(tree_key) {
+                TreeKeyIdx treenode = *tree_key;
+		treenode.setText(key);
+                display_mod->SetKey(treenode);
+		display_mod->KeyText();      //snap to entry
+		return treenode.getOffset();
+	}
+	return 0;
+}
 void BackEnd::set_treekey(unsigned long offset) {
 	if(tree_key)
 		delete tree_key;
@@ -1006,7 +1017,7 @@ unsigned long BackEnd::get_treekey_offset_from_key(const char * module_name, con
 }
 
 
-unsigned long BackEnd::get_treekey_offset(void) {
+unsigned long BackEnd::get_treekey_offset(void) {	
         if (tree_key) 
                 return tree_key->getOffset();
         return 0;
@@ -1031,6 +1042,15 @@ int BackEnd::treekey_first_child(unsigned long offset) {
 }
 
 
+int BackEnd::treekey_parent(unsigned long offset) {
+        if (tree_key) {
+                tree_key->setOffset(offset);
+		return tree_key->parent();
+	}
+        return false;
+}
+
+
 char *BackEnd::treekey_get_local_name(unsigned long offset) {	
         if (tree_key) {
                 tree_key->setOffset(offset);
@@ -1052,6 +1072,18 @@ int BackEnd::treekey_next_sibling(unsigned long offset) {
 }
 
 
+
+int BackEnd::treekey_prev_sibling(unsigned long offset) {
+        if (tree_key) {
+                tree_key->setOffset(offset);
+                if(tree_key->previousSibling()) {
+			return 1;
+		}	
+        }
+        return 0;
+}
+
+
 char *BackEnd::navigate_module(int direction) {
 	char *retval = NULL;                                      
         gsize bytes_read;
@@ -1076,7 +1108,7 @@ char *BackEnd::navigate_module(int direction) {
 			     &bytes_read,
 			     &bytes_written,
 			     error);
-	return retval; //strdup((char *) display_mod->KeyText());
+	return strdup((char *) display_mod->KeyText());
 }
 
 GList *BackEnd::parse_verse_list(const char * list, char * current_key) {
@@ -1099,7 +1131,7 @@ GList *BackEnd::parse_verse_list(const char * list, char * current_key) {
 				     error);
 	
 	key.setText(m_current_key);
-	vs = key.ParseVerseList(list, key);
+	vs = key.ParseVerseList(list, key,TRUE);
 	g_free(m_current_key);
 	if(!vs.Count())
 		return retlist;
@@ -1221,6 +1253,7 @@ int BackEnd::do_module_search(char *module_name, const char *search_string,
 				int search_type, int search_params, int is_dialog) {
 	char progressunits = 70;
 	results.ClearList();
+	//search_scope_list.ClearList()
 	search_mod = NULL;
 
 	search_mod = main_mgr->Modules[module_name];
@@ -1236,6 +1269,8 @@ int BackEnd::do_module_search(char *module_name, const char *search_string,
 				:main_sidebar_search_percent_update,
 				(void *) &progressunits);
 	search_scope_list = results;
+	if(search_type == -4)
+		results.sort();
 	return results.Count();
 }
  
@@ -1330,7 +1365,7 @@ void BackEnd::init_language_map(void) {
 	//languageMap[SWBuf("lb")] = SWBuf("Letzeburgesch");
 	//languageMap[SWBuf("ln")] = SWBuf("Lingala");
 	//languageMap[SWBuf("lo")] = SWBuf("Lao");
-	languageMap[SWBuf("lt")] = SWBuf("Lithuanian"); /* done */
+	languageMap[SWBuf("lt")] = SWBuf(_("Lithuanian")); /* done */
 	languageMap[SWBuf("lv")] = SWBuf(_("Latvian")); /* done */
 	//languageMap[SWBuf("mg")] = SWBuf("Malagasy");
 	//languageMap[SWBuf("mh")] = SWBuf("Marshall");
@@ -1408,9 +1443,9 @@ void BackEnd::init_language_map(void) {
 	//languageMap[SWBuf("ur")] = SWBuf("Urdu");
 	//languageMap[SWBuf("uz")] = SWBuf("Uzbek");
 	languageMap[SWBuf("vi")] = SWBuf(_("Vietnamese")); /* done */
-	//languageMap[SWBuf("vo")] = SWBuf("Volapük");
+	languageMap[SWBuf("vo")] = SWBuf("Volapük");/* if commented,  accentued u causes gettext problems */
 /*  */	//languageMap[SWBuf("wo")] = SWBuf("Wolof");
-	languageMap[SWBuf("xh")] = SWBuf("Xhosa"); /* causes gettext problems */
+	languageMap[SWBuf("xh")] = SWBuf(_("Xhosa"));
 	languageMap[SWBuf("x-E-BAR")] = SWBuf(_("Bavarian")); /* done */
 	languageMap[SWBuf("x-E-GSW")] = SWBuf(_("Alemannisch")); /* done */
 /*  */	languageMap[SWBuf("x-E-HAT")] = SWBuf(_("Haitian Creole French")); /* done */
