@@ -143,7 +143,7 @@ delete_note_cb(GtkWidget * widget, gpointer data)
 	gchar *buf = NULL;
 	EDITOR *e = (EDITOR *) data;
 	
-	if(e->studypad)
+	if (e->studypad)
 		return;
 	
 	info = gui_new_dialog();
@@ -152,7 +152,7 @@ delete_note_cb(GtkWidget * widget, gpointer data)
 		    ("<span weight=\"bold\" size=\"larger\">%s %s?</span>",
 		    _("Are you sure you want to delete the note for") , e->key);
 		info->label_top = buf;
-		info->label2 =  N_("It will be lost permanently!");
+		info->label2 =  _("It will be lost permanently!");
 		info->yes = TRUE;
 		info->cancel = TRUE;
 
@@ -170,7 +170,8 @@ save_through_persist_stream_cb(GtkWidget * widget, gpointer data)
 {
 	BonoboObject *smem;
 	CORBA_Environment ev;
-	const char *text;
+	const gchar *text;
+	gchar *buf;
 	size_t len;
 	EDITOR *ed = (EDITOR *) data;
 
@@ -182,6 +183,10 @@ save_through_persist_stream_cb(GtkWidget * widget, gpointer data)
 	bonobo_stream_client_write(BONOBO_OBJREF(smem), "", 1, &ev);
 
 	text = bonobo_stream_mem_get_buffer(BONOBO_STREAM_MEM(smem));
+	buf = strdup(text);
+	// converts encoding from ncr to utf8
+	text = ncr_to_utf8(buf);
+	g_free(buf);
 #ifdef DEBUG
 	g_message(text);
 #endif
@@ -266,8 +271,8 @@ save_through_persist_file(EDITOR * e, const gchar * filename)
 		CORBA_exception_free(&ev);
 		return FALSE;
 	}
-	if(!e->filename || strcmp(e->filename, filename)) {
-		if(e->filename)
+	if (!e->filename || strcmp(e->filename, filename)) {
+		if (e->filename)
 			g_free(e->filename);
 		e->filename = g_strdup(filename);
 		xml_set_value("GnomeSword", "studypad", "lastfile",
@@ -473,7 +478,7 @@ add_bookmark_cb(GtkWidget * widget, gpointer data)
 	EDITOR *e = (EDITOR *) data;
 	gchar *label = NULL;
 	
-	if(e->studypad) {
+	if (e->studypad) {
 		label = g_strdup_printf("%s, %s",e->filename, "studypad");
 		gui_bookmark_dialog(label, "studypad", e->filename);
 		g_free(label);
@@ -501,7 +506,7 @@ save_through_persist_file_cb(GtkWidget * widget, gpointer data)
 {
 	gchar *filename = NULL;
 	EDITOR *e = (EDITOR *) data;
-	if(e->filename) {
+	if (e->filename) {
 		filename = g_strdup(e->filename);
 		save_through_persist_file(e, filename);
 	}
@@ -531,17 +536,16 @@ gint ask_about_saving(EDITOR * e)
 		if (settings.studypadfilename)
 			buf = settings.studypadfilename;
 		else
-			buf = N_("File");
-		buf1 = N_("Save the changes to document");
-		buf2 = N_("before closing?");
+			buf = _("File");
+		buf1 = _("Save the changes to document");
+		buf2 = _("before closing?");
 		buf3 =
 		    g_strdup_printf
 		    ("<span weight=\"bold\" size=\"larger\">%s %s %s</span>",
 		     buf1, buf, buf2);
 		info->label_top = buf3;
 		info->label2 =
-		    N_
-		    ("If you don't save, changes will be permanently lost.");
+		    _("If you don't save, changes will be permanently lost.");
 		info->save = TRUE;
 		info->cancel = TRUE;
 		info->no_save = TRUE;
@@ -623,9 +627,9 @@ gboolean editor_close_all(void)
 #ifdef DEBUG
 	g_message("number of editors = %d",g_list_length(tmp));
 #endif
-	while(tmp != NULL) {
+	while (tmp != NULL) {
 		e = (EDITOR*)tmp->data;
-		if(e->window)
+		if (e->window)
 			do_exit(e);			
 		tmp = g_list_next(tmp);
 	}
@@ -640,26 +644,27 @@ editor_load_note(EDITOR * e, const gchar * module_name,
 	gchar *title;
 	gchar *text;
 	
-	if(editor_is_dirty(e))
+	if (editor_is_dirty(e))
 		save_through_persist_stream_cb(NULL, e);
 	
-	if(module_name) {
-		if(e->module)
+	if (module_name) {
+		if (e->module)
 			g_free(e->module);
 		e->module = g_strdup(module_name);
 	}
-	if(key) {	
-		if(e->key) 
+	if (key) {	
+		if (e->key) 
 			g_free(e->key);
 		e->key = g_strdup(key);
 	}
 		
 	
 	title = g_strdup_printf("%s - %s", e->module, e->key);
-	text = main_get_rendered_text((gchar *) e->module,
+	text = main_get_raw_text((gchar *) e->module,
 				   (gchar *) e->key);
-
-	load_through_persist_stream(text, e);
+	if(strlen(text)) 
+		load_through_persist_stream(text, e);
+	
 	change_window_title(e->window, title);
 	main_navbar_set(e->navbar, e->key);
 	
@@ -948,8 +953,8 @@ static void on_entry_activate(GtkEntry * entry, EDITOR * e)
 
 static void sync_toggled(GtkToggleButton * button, EDITOR * e)
 {
-	if(button->active) {
-		if(editor_is_dirty(e))
+	if (button->active) {
+		if (editor_is_dirty(e))
 			save_through_persist_stream_cb(NULL, (EDITOR*)e);
 		editor_load_note(e, NULL,settings.currentverse);
 		e->sync = TRUE;
@@ -965,9 +970,9 @@ void editor_sync_with_main(void)
 	EDITOR * e;
 	
 	tmp = g_list_first(editors_all);
-	while(tmp != NULL) {
+	while (tmp != NULL) {
 		e = (EDITOR*)tmp->data;
-		if(!e->studypad) 
+		if (!e->studypad) 
 			sync_toggled(GTK_TOGGLE_BUTTON(e->sync_button), e);
 		tmp = g_list_next(tmp);
 	}
@@ -1123,11 +1128,13 @@ static GtkWidget *container_create(const gchar * window_title,
 	
 	vbox = gtk_vbox_new(FALSE, 6);
 	gtk_widget_show(vbox);
-	if(!editor->studypad) {
+	if (!editor->studypad) {
 		toolbar_nav = navebar_create(editor);
 		gtk_widget_show(toolbar_nav);
 		gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET(toolbar_nav), FALSE, TRUE, 0);
 		editor->navbar.module_name = editor->module;
+		if (editor->navbar.key == NULL)
+			editor->navbar.key = g_strdup(editor->key);
 		main_navbar_fill_book_combo(editor->navbar);
 	}
 
@@ -1272,9 +1279,10 @@ gint _create_new(const gchar * filename, const gchar * key, gint note)
 		editor->filename = NULL;
 		widgets.studypad_dialog =
 		    container_create(_("StudyPad"), editor);
-		if (filename)
+		if (filename) {
 			editor->filename = g_strdup(filename);
-		load_through_persist_file(editor, g_strdup(filename));
+			load_through_persist_file(editor, g_strdup(filename));
+		}
 		settings.studypad_dialog_exist = TRUE;
 	}
 	if (editor->html_widget) {
@@ -1314,16 +1322,16 @@ gint editor_create_new(const gchar * filename, const gchar * key, gint note)
 	EDITOR *e;
 	
 	tmp = g_list_first(editors_all);
-	while(tmp != NULL) {
+	while (tmp != NULL) {
 		e = (EDITOR*)tmp->data;
-		if(note && !e->studypad) {
-			if(editor_is_dirty(e))
+		if (note && !e->studypad) {
+			if (editor_is_dirty(e))
 				save_through_persist_stream_cb(NULL, 
 						(EDITOR*)e);
-			if(e->module)
+			if (e->module)
 				g_free(e->module);
 			e->module = g_strdup(filename);
-			if(e->key)
+			if (e->key)
 				g_free(e->key);
 			e->key = g_strdup(key);
 			gtk_widget_show(e->window);
@@ -1332,12 +1340,12 @@ gint editor_create_new(const gchar * filename, const gchar * key, gint note)
 			editor_load_note(e, NULL, NULL);
 			return 1;
 		}
-		if(!note && e->studypad) {
-			if(editor_is_dirty(e))
+		if (!note && e->studypad) {
+			if (editor_is_dirty(e))
 				save_through_persist_file(e, 
 						g_strdup(e->filename));
 				
-			if(e->filename)
+			if (e->filename)
 				g_free(e->filename);
 			e->filename = g_strdup(filename);
 			gtk_widget_show(e->window);
