@@ -62,6 +62,7 @@
 #include "main/xml.h"
 #include "main/global_ops.hh"
 #include "main/embed.h"
+#include "main/display.hh"
 
 
 gboolean shift_key_presed = FALSE;
@@ -304,7 +305,7 @@ static gboolean on_key_press_event           (GtkWidget       *widget,
 		break;
 	}
 #ifdef DEBUG
-	g_message("on_key_press_event");
+	g_message("on_key_press_event\nkeycode: %d",event->hardware_keycode);
 #endif
   	return FALSE;
 }
@@ -320,6 +321,9 @@ static gboolean on_key_release_event         (GtkWidget       *widget,
 			shift_key_presed = FALSE;
 		break;
 	}
+#ifdef DEBUG
+	g_message("on_key_release_event\nkeycode: %d",event->hardware_keycode);
+#endif
   	return FALSE;
 }
 
@@ -689,6 +693,19 @@ on_set_module_font_activate(GtkMenuItem * menuitem, gpointer user_data)
 	g_free(url);
 }
 
+static void on_read_selection_aloud(GtkMenuItem * menuitem,
+				    gpointer user_data)
+{
+	GtkHTML *html = GTK_HTML(widgets.html_text);
+	int len;
+	gchar *dict_key = gtk_html_get_selection_html(html, &len);
+
+	if (dict_key && len && (*dict_key != '\0')) {
+		ReadAloud(0, dict_key);
+		g_free(dict_key);
+	} else
+		gui_generic_warning("No selection made");
+}
 
 static void on_use_current_dictionary_activate(GtkMenuItem * menuitem,
 				   		gpointer user_data)
@@ -761,7 +778,7 @@ on_secondary_reading_activate(GtkMenuItem * menuitem,
 					 gchar * dict_mod_description)
  *
  * Description
- *   lookup seledtion in a dict/lex module
+ *   lookup selection in a dict/lex module
  *
  * Return value
  *   void
@@ -787,11 +804,12 @@ void gui_lookup_bibletext_selection(GtkMenuItem * menuitem,
 	g_message("gui_lookup_bibletext_selection\ndict_key: %s",dict_key);
 #endif
 #endif
-	if (dict_key && mod_name) {
+	if (dict_key && mod_name)
 		main_display_dictionary(mod_name, dict_key);
+	if (dict_key)
 		g_free(dict_key);
+	if (mod_name)
 		g_free(mod_name);
-	}
 }
 
 /******************************************************************************
@@ -1093,6 +1111,12 @@ static GnomeUIInfo menu1_uiinfo[] = {
 	 NULL,
 	 (gpointer) on_unlock_module_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, "gnome-stock-authentication",
+	 0, (GdkModifierType) 0, NULL},
+	{
+	 GNOME_APP_UI_ITEM, N_("Read Selection Aloud"),
+	 NULL,
+	 (gpointer) on_read_selection_aloud, NULL, NULL,
+	 GNOME_APP_PIXMAP_STOCK, "gnome-stock-mic",
 	 0, (GdkModifierType) 0, NULL},	
 	GNOMEUIINFO_END
 };
@@ -1129,8 +1153,8 @@ void create_menu(void)
 	gtk_widget_hide(module_options_menu_uiinfo[11].widget);	//"headings"
 	gtk_widget_hide(module_options_menu_uiinfo[12].widget);	//"variants"
 	gtk_widget_hide(menu1_uiinfo[7].widget);	//"unlock_module"
-	gtk_widget_hide(menu1_uiinfo[8].widget);
-	gtk_widget_hide(menu1_uiinfo[9].widget);
+	//gtk_widget_hide(menu1_uiinfo[8].widget);
+	//gtk_widget_hide(menu1_uiinfo[9].widget);
 
 
 
