@@ -48,7 +48,8 @@
 #include "main/settings.h"
 #include "main/lists.h"
 #include "main/xml.h"
- 
+#include "main/display.hh"
+
 static void create_menu(DIALOG_DATA * t ,GdkEventButton * event);
 
 /******************************************************************************
@@ -688,8 +689,7 @@ void on_comboboxentry5_changed(GtkComboBox * combobox, DIALOG_DATA * c)
 	gtk_tree_model_get(GTK_TREE_MODEL(model), &iter,
 			   0, &chapter, -1);
 
-	url = g_strdup_printf("sword:///%s %s:1",
-			      settings.MainWindowModule, book, chapter);
+	url = g_strdup_printf("sword:///%s %s:1", book, chapter);
 	buf = g_strdup_printf("%s %s:1", book, chapter);
 	main_dialogs_url_handler(c, url, TRUE);
 	main_navbar_set(c->navbar, buf);
@@ -1439,6 +1439,19 @@ on_set_module_font_activate(GtkMenuItem * menuitem, gpointer user_data)
 	g_free(url);
 }
 
+static void on_read_selection_aloud(GtkMenuItem * menuitem,
+				    gpointer user_data)
+{
+	GtkHTML *html = GTK_HTML(cur_vt->html);
+	int len;
+	gchar *dict_key = gtk_html_get_selection_html(html, &len);
+
+	if (dict_key && len && (*dict_key != '\0')) {
+		ReadAloud(0, dict_key);
+		g_free(dict_key);
+	} else
+		gui_generic_warning("No selection made");
+}
 
 static void on_use_current_dictionary_activate(GtkMenuItem * menuitem,
 				   		gpointer user_data)
@@ -1512,7 +1525,7 @@ on_secondary_reading_activate(GtkMenuItem * menuitem,
 					 gchar * dict_mod_description)
  *
  * Description
- *   lookup seledtion in a dict/lex module
+ *   lookup selection in a dict/lex module
  *
  * Return value
  *   void
@@ -2149,6 +2162,12 @@ static GnomeUIInfo menu1_uiinfo[] = {
 	 (gpointer) on_unlock_module_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, "gnome-stock-authentication",
 	 0, (GdkModifierType) 0, NULL},
+	{
+	 GNOME_APP_UI_ITEM, N_("Read Selection Aloud"),
+	 NULL,
+	 (gpointer) on_read_selection_aloud, NULL, NULL,
+	 GNOME_APP_PIXMAP_STOCK, "gnome-stock-mic",
+	 0, (GdkModifierType) 0, NULL},
 	GNOMEUIINFO_END
 };
 
