@@ -99,10 +99,10 @@ void gui_verselist_to_bookmarks(GList * verses)
 	gtk_tree_model_get_iter_first(GTK_TREE_MODEL(model), &iter);
 	info = gui_new_dialog();
 	info->stock_icon = GTK_STOCK_OPEN;
-	info->title = N_("Bookmark");
-	info->label_top = N_("Enter Folder Name");
+	info->title = _("Bookmark");
+	info->label_top = _("Enter Folder Name");
 	info->text1 = g_strdup(settings.searchText);
-	info->label1 = N_("Folder: ");
+	info->label1 = _("Folder: ");
 	info->ok = TRUE;
 	info->cancel = TRUE;
 
@@ -147,7 +147,7 @@ void gui_verselist_to_bookmarks(GList * verses)
 	}
 	g_free(info->text1);
 	g_free(info);
-	gtk_widget_set_sensitive(sidebar.menu_item_save_search, FALSE);
+//	gtk_widget_set_sensitive(sidebar.menu_item_save_search, FALSE);
 }
 
 /******************************************************************************
@@ -906,7 +906,7 @@ GtkWidget *gui_create_bookmark_tree(void)
 	gtk_tree_store_set(GTK_TREE_STORE(tree_model), &iter,
 			   COL_OPEN_PIXBUF, bm_pixbufs->pixbuf_opened,
 			   COL_CLOSED_PIXBUF, bm_pixbufs->pixbuf_closed,
-			   COL_CAPTION, "Bookmarks",
+			   COL_CAPTION, _("Bookmarks"),
 			   COL_KEY, NULL, COL_MODULE, NULL, -1);
 
 	load_xml_bookmarks(GTK_TREE_VIEW(tree), &iter);
