@@ -24,12 +24,12 @@
 #endif
 
 #include <gnome.h>
+#include <gtkhtml/gtkhtml.h>
 #ifdef USE_GTKMOZEMBED
 #include <gtkmozembed.h>
 #include "main/embed.h"
 #include "main/embed-dialogs.h"
 #else
-#include <gtkhtml/gtkhtml.h>
 #include "gui/html.h"
 #endif
 
@@ -40,16 +40,11 @@
 #include "gui/sidebar.h"
 #include "gui/widgets.h"
 
-#ifndef USE_GTKHTML38
-#include "editor/editor_menu.h"
-#include "editor/toolbar_style.h"
-#include "editor/toolbar_edit.h"
-#endif
 #include "main/lists.h"
 #include "main/navbar.h"
 #include "main/settings.h"
 #include "main/sword.h"
-
+#include "main/display.hh"
 
 static void create_menu(DIALOG_DATA * d, GdkEventButton * event);
 
@@ -677,8 +672,7 @@ static void on_comboboxentry5_changed(GtkComboBox * combobox, DIALOG_DATA * d)
 	gtk_tree_model_get(GTK_TREE_MODEL(model), &iter,
 			   0, &chapter, -1);
 
-	url = g_strdup_printf("sword:///%s %s:1",
-			      settings.MainWindowModule, book, chapter);
+	url = g_strdup_printf("sword:///%s %s:1", book, chapter);
 	buf = g_strdup_printf("%s %s:1", book, chapter);
 	main_dialogs_url_handler(d, url, TRUE);
 	main_navbar_set(d->navbar, buf);
@@ -742,6 +736,34 @@ static void on_comboboxentry6_changed(GtkComboBox * combobox, DIALOG_DATA * d)
 	g_free(buf);
 }
 
+/******************************************************************************
+ * Name
+ *   commentary_prefixable_link
+ *
+ * Synopsis
+ *   #include ".h"
+ *
+ *   void commentary_prefixable_link(void)	
+ *
+ * Description
+ *    front-end-ish handler for xref clicks, to supply book name to prefix.
+ *
+ * Return value
+ *   void
+ */
+
+void commentary_prefixable_link(GtkHTML * html,
+				const gchar * url,
+				gpointer data)
+{
+	gchar buf[32];
+
+	cur_d = data;
+	strcpy(buf, cur_d->key);
+	*(strrchr(buf, ' ')) = '\0';
+	gui_prefixable_link_clicked(html, url, data, buf);
+}
+
 /******************************************************************************
  * Name
  *   create_nav_toolbar
@@ -989,7 +1011,7 @@ void gui_create_commentary_dialog(DIALOG_DATA * d, gboolean do_edit)
 				 G_CALLBACK(html_key_press_event), d);
 		g_signal_connect(GTK_OBJECT(ec->htmlwidget),
 				 "link_clicked",
-				 G_CALLBACK(gui_link_clicked), NULL);
+				 G_CALLBACK(commentary_prefixable_link), NULL);
 
 		g_signal_connect(GTK_OBJECT(ec->htmlwidget),
 				 "on_url", G_CALLBACK(gui_url), NULL);
@@ -1012,7 +1034,7 @@ void gui_create_commentary_dialog(DIALOG_DATA * d, gboolean do_edit)
 
 		g_signal_connect(GTK_OBJECT(d->html),
 				 "link_clicked",
-				 G_CALLBACK(gui_link_clicked), d);
+				 G_CALLBACK(commentary_prefixable_link), d);
 		g_signal_connect(GTK_OBJECT(d->html), "on_url",
 				 G_CALLBACK(dialog_url), d);
 		g_signal_connect(GTK_OBJECT(d->html),
@@ -1089,6 +1111,19 @@ on_set_module_font_activate(GtkMenuItem * menuitem, gpointer user_data)
 	g_free(url);
 }
 
+static void on_read_selection_aloud(GtkMenuItem * menuitem,
+				    gpointer user_data)
+{
+	GtkHTML *html = GTK_HTML(cur_d->html);
+	int len;
+	gchar *dict_key = gtk_html_get_selection_html(html, &len);
+
+	if (dict_key && len && (*dict_key != '\0')) {
+		ReadAloud(0, dict_key);
+		g_free(dict_key);
+	} else
+		gui_generic_warning("No selection made");
+}
 
 static void on_use_current_dictionary_activate(GtkMenuItem * menuitem,
 					       gpointer user_data)
@@ -1157,7 +1192,7 @@ on_secondary_reading_activate(GtkMenuItem * menuitem,
 					 gchar * dict_mod_description)
  *
  * Description
- *   lookup seledtion in a dict/lex module
+ *   lookup selection in a dict/lex module
  *
  * Return value
  *   void
@@ -1850,6 +1885,12 @@ static GnomeUIInfo menu1_uiinfo[] = {
 	 (gpointer) on_chapter_heading_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, "gtk-open",
 	 0, (GdkModifierType) 0, NULL},
+	{
+	 GNOME_APP_UI_ITEM, N_("Read Selection Aloud"),
+	 NULL,
+	 (gpointer) on_read_selection_aloud, NULL, NULL,
+	 GNOME_APP_PIXMAP_STOCK, "gnome-stock-mic",
+	 0, (GdkModifierType) 0, NULL},
 	GNOMEUIINFO_END
 };
 
