@@ -512,17 +512,6 @@ GtkWidget *gui_create_dictionary_pane(void)
 	gtk_widget_show(hbox2);
 	gtk_box_pack_start(GTK_BOX(box_dict), hbox2, FALSE, FALSE, 0);
 
-	button10 = gtk_button_new();
-	gtk_widget_show(button10);
-	gtk_box_pack_start(GTK_BOX(hbox2), button10, FALSE, FALSE, 0);
-	gtk_button_set_relief(GTK_BUTTON(button10), GTK_RELIEF_NONE);
-
-	image1 =
-	    gtk_image_new_from_stock("gtk-go-back",
-				     GTK_ICON_SIZE_BUTTON);
-	gtk_widget_show(image1);
-	gtk_container_add(GTK_CONTAINER(button10), image1);
-	
   	widgets.entry_dict = gtk_entry_new ();
   	gtk_widget_show (widgets.entry_dict);
 	gtk_box_pack_start(GTK_BOX(hbox2), widgets.entry_dict, TRUE, TRUE, 0);
@@ -536,14 +525,26 @@ GtkWidget *gui_create_dictionary_pane(void)
   	gtk_widget_show (arrow1);
   	gtk_container_add (GTK_CONTAINER (dict_drop_down), arrow1);
 	
+	button10 = gtk_button_new();
+	gtk_widget_show(button10);
+	gtk_box_pack_start(GTK_BOX(hbox2), button10, FALSE, FALSE, 0);
+	gtk_button_set_relief(GTK_BUTTON(button10), GTK_RELIEF_NONE);
+
+  	image1 = gtk_image_new_from_icon_name ("stock_up", GTK_ICON_SIZE_BUTTON);
+	/*image1 =
+	    gtk_image_new_from_stock("gtk-go-back",
+				     GTK_ICON_SIZE_BUTTON);*/
+	gtk_widget_show(image1);
+	gtk_container_add(GTK_CONTAINER(button10), image1);
+	
 	button11 = gtk_button_new();
 	gtk_widget_show(button11);
 	gtk_box_pack_start(GTK_BOX(hbox2), button11, FALSE, FALSE, 0);
 	gtk_button_set_relief(GTK_BUTTON(button11), GTK_RELIEF_NONE);
 
-	image2 =
-	    gtk_image_new_from_stock("gtk-go-forward",
-				     GTK_ICON_SIZE_BUTTON);
+	image2 = gtk_image_new_from_icon_name ("stock_down", GTK_ICON_SIZE_BUTTON);
+	   /* gtk_image_new_from_stock("gtk-go-forward",
+				     GTK_ICON_SIZE_BUTTON);*/
 	gtk_widget_show(image2);
 	gtk_container_add(GTK_CONTAINER(button11), image2);
 
@@ -642,9 +643,9 @@ GtkWidget *gui_create_dictionary_pane(void)
 
 static void on_global_option(GtkMenuItem * menuitem, gpointer data)
 {
-/*	save_module_options(settings.MainWindowModule, (gchar *) data,
+	main_save_module_options(settings.DictWindowModule, (gchar *) data,
 			    GTK_CHECK_MENU_ITEM(menuitem)->active);
-	gui_display_text(settings.currentverse);*/
+	main_display_dictionary(settings.DictWindowModule, settings.dictkey);
 }
 
 
