@@ -331,7 +331,23 @@ static void add_columns(GtkTreeView * treeview)
 
 void on_btnSyncDL_clicked(GtkButton * button, DIALOG_DATA * d)
 {
-	gtk_entry_set_text(GTK_ENTRY(d->entry), settings.dictkey);
+	gchar *key = NULL;
+	gchar *key2 = NULL;
+	gsize bytes_read;
+	gsize bytes_written;
+	GError **error = NULL;
+
+	key=settings.dictkey;
+	key2 = g_convert(  key,	
+			     -1,	
+			     OLD_CODESET,	
+			     UTF_8,	
+			     &bytes_read,	
+			     &bytes_written,
+			     error);
+	gtk_entry_set_text(GTK_ENTRY(d->entry), key2);
+//	g_free(key1);
+//	g_free(key2);
 }
 
 /******************************************************************************
@@ -350,14 +366,32 @@ void on_btnSyncDL_clicked(GtkButton * button, DIALOG_DATA * d)
  *   void
  */
 
-static void entery_changed(GtkEditable * editable, DIALOG_DATA * d)
+static void entry_changed(GtkEditable * editable, DIALOG_DATA * d)
 {
+	gchar *key = NULL;
+	gchar *key2 = NULL;
+	gsize bytes_read;
+	gsize bytes_written;
+	GError **error = NULL;
+	
 	if (d->key)
 		g_free(d->key);
-	d->key =
-	    g_strdup((gchar *) gtk_entry_get_text(GTK_ENTRY(d->entry)));
 
-	main_dialogs_dictionary_entery_changed(d);
+	key=
+	    g_strdup((gchar *) gtk_entry_get_text(GTK_ENTRY(d->entry)));
+	key2 = g_convert(  key,	
+			     -1,	
+			     UTF_8,	
+			     OLD_CODESET,	
+			     &bytes_read,	
+			     &bytes_written,
+			     error);
+
+	d->key = g_utf8_strup(key2, -1);
+;
+//	g_message(f_message,407,"entry_changedl",d->key);    
+
+	main_dialogs_dictionary_entry_changed(d);
 }
 
 
@@ -530,7 +564,7 @@ void gui_create_dictlex_dialog(DIALOG_DATA * dlg)
 	g_signal_connect(GTK_OBJECT(btnSyncDL), "clicked",
 			 G_CALLBACK(on_btnSyncDL_clicked), dlg);
 	g_signal_connect(GTK_OBJECT(dlg->entry), "changed",
-			 G_CALLBACK(entery_changed),
+			 G_CALLBACK(entry_changed),
 			 (DIALOG_DATA *) dlg);
 	g_signal_connect(G_OBJECT(dlg->listview),
 			 "button_release_event",
