@@ -52,6 +52,7 @@
 #include "gui/shortcutbar_search.h"
 #include "gui/font_dialog.h"
 #include "gui/widgets.h"
+#include "gui/navbar_book.h"
 
 #include "main/embed.h"
 #include "main/settings.h"
@@ -59,6 +60,7 @@
 #include "main/global_ops.hh"
 #include "main/sword.h"
 #include "main/xml.h"
+#include "main/display.hh"
 
 static void create_menu(GdkEventButton * event);
 
@@ -159,16 +161,10 @@ static gboolean on_book_button_release_event(GtkWidget * widget,
 	case 2:
 		if (!in_url)
 			break;
-#ifdef USE_GTKHTML38
 		url = gtk_html_get_url_at (GTK_HTML(widgets.html_text),		
 								event->x,
 								event->y);
-#else
-		url = html_engine_get_link_at (GTK_HTML(widgets.html_book)->engine,
-					 event->x,
-					 event->y);
-#endif
-		if(strstr(url,"sword://")) {
+		if(url && (strstr(url,"sword://"))) {
 			gchar **work_buf = g_strsplit (url,"/",4);
 			gui_open_passage_in_new_tab(work_buf[3]);
 			g_strfreev(work_buf);
@@ -306,17 +302,18 @@ GtkWidget *gui_create_book_pane(void)
 	GtkWidget *box;
 	GtkWidget *scrolledwindow;
 	GtkWidget *eventbox;	
+	GtkWidget *navbar;
 	
 	box = gtk_vbox_new(FALSE, 0);
 	gtk_widget_show(box);
 
+	navbar = gui_navbar_book_new();
+	gtk_box_pack_start(GTK_BOX(box), navbar, FALSE, FALSE, 0);
 
 #ifdef USE_GTKMOZEMBED	
 	eventbox = gtk_event_box_new ();
 	gtk_widget_show (eventbox);
-	gtk_box_pack_start(GTK_BOX(box),
-			   eventbox, TRUE,
-			   TRUE, 0);
+	gtk_box_pack_start(GTK_BOX(box), eventbox, TRUE, TRUE, 0);
 	widgets.html_book = embed_new(BOOK_TYPE);
 	gtk_widget_show(widgets.html_book);
 	gtk_container_add(GTK_CONTAINER(eventbox),
@@ -329,9 +326,7 @@ GtkWidget *gui_create_book_pane(void)
 #else
 	scrolledwindow = gtk_scrolled_window_new(NULL, NULL);
 	gtk_widget_show(scrolledwindow);
-	gtk_box_pack_start(GTK_BOX(box),
-			   scrolledwindow, TRUE,
-			   TRUE, 0);
+	gtk_box_pack_start(GTK_BOX(box), scrolledwindow, TRUE, TRUE, 0);
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW
 				       (scrolledwindow),
 				       GTK_POLICY_AUTOMATIC,
@@ -447,6 +442,19 @@ on_set_module_font_activate(GtkMenuItem * menuitem, gpointer user_data)
 	main_display_book(settings.book_mod,xml_get_value( "keys", "offset"));
 }
 
+static void on_read_selection_aloud(GtkMenuItem * menuitem,
+				    gpointer user_data)
+{
+	GtkHTML *html = GTK_HTML(widgets.html_book);
+	int len;
+	gchar *dict_key = gtk_html_get_selection_html(html, &len);
+
+	if (dict_key && len && (*dict_key != '\0')) {
+		ReadAloud(0, dict_key);
+		g_free(dict_key);
+	} else
+		gui_generic_warning("No selection made");
+}
 
 static void
 on_use_current_dictionary_activate(GtkMenuItem * menuitem,
@@ -522,7 +530,7 @@ on_secondary_reading_activate(GtkMenuItem * menuitem,
 					 gchar * dict_mod_description)
  *
  * Description
- *   lookup seledtion in a dict/lex module
+ *   lookup selection in a dict/lex module
  *
  * Return value
  *   void
@@ -858,6 +866,12 @@ static GnomeUIInfo menu1_uiinfo[] = {
 	 (gpointer) on_unlock_module_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, "gnome-stock-authentication",
 	 0, (GdkModifierType) 0, NULL},
+	{
+	 GNOME_APP_UI_ITEM, N_("Read Selection Aloud"),
+	 NULL,
+	 (gpointer) on_read_selection_aloud, NULL, NULL,
+	 GNOME_APP_PIXMAP_STOCK, "gnome-stock-mic",
+	 0, (GdkModifierType) 0, NULL},
 	GNOMEUIINFO_END
 };
 
