@@ -26,10 +26,6 @@
 #include <gnome.h>
 #include <gtkhtml/gtkhtml.h>
 
-#ifndef USE_GTKHTML38
-#include <gtkhtml/htmlengine-print.h>
-#include <gtkhtml/htmlselection.h>
-#endif
 #include <libgnomeprint/gnome-print.h>
 #include <libgnomeprintui/gnome-print-dialog.h>
 #include <libgnomeprintui/gnome-print-job-preview.h>
@@ -37,7 +33,6 @@
 
 #include "gui/html.h"
 #include "gui/gnomesword.h"
-#include "editor/editor.h"
 #include "gui/sidebar.h"
 #include "gui/shortcutbar_main.h"
 #include "gui/parallel_view.h"
@@ -184,9 +179,6 @@ void gui_url(GtkHTML * html, const gchar * url, gpointer data)
 
 void gui_link_clicked(GtkHTML * html, const gchar * url, gpointer data)
 {
-	gchar *buf = NULL;
-	gchar tmpbuf[255];
-	gint i = 0;
 	
 	if(main_url_handler(url, TRUE))
 		return;
@@ -203,6 +195,58 @@ void gui_link_clicked(GtkHTML * html, const gchar * url, gpointer data)
 }
 
 
+/******************************************************************************
+ * Name
+ *   gui_prefixable_link_clicked
+ *
+ * Synopsis
+ *   #include "gui/html.h"
+ *
+ *   void gui_prefixable_link_clicked(GtkHTML * html,
+ *				      const gchar * url,
+ *				      gpointer data,
+ *				      const gchar * book)
+ *
+ * Description
+ *   html link clicked.  possibly prefix url with current book name.
+ *
+ * Return value
+ *   void
+ */
+
+void gui_prefixable_link_clicked(GtkHTML * html,
+				 const gchar * url,
+				 gpointer data,
+				 const gchar * book)
+{
+	gchar *buf, *place;
+	gchar tmpbuf[1023];
+	
+	if (buf = strstr(url, "&value=")) {
+		buf += 7;
+		place = buf;
+
+		while (*buf && isdigit(*buf))
+			buf++;
+		if ((*buf == ':') || strncmp(buf, "%3A", 3) == 0) {
+			/* url begins w/"digits:" only: fix */
+			strncpy(tmpbuf, url, place - url);
+			strcpy(tmpbuf+(place-url), book);
+			strcat(tmpbuf, place);
+			url = tmpbuf;
+		}
+	}
+	if (main_url_handler(url, TRUE))
+		return;
+	
+	if (*url == '@') {
+		++url;
+		main_swap_parallel_with_main((gchar *) url);
+		return;
+	}
+}
+
+
 /******************************************************************************
  * Name
  *   gui_copy_html
@@ -311,11 +355,11 @@ gchar *gui_get_word_or_selection(GtkWidget * html_widget, gboolean word)
 	key = gtk_html_get_selection_html (html, &len);
 	if ((key == NULL) || (*key == '\0'))
 	{
-	    gui_generic_warning("No selection provided\nSubstituting `Jesus'");
-	    key = ">Jesus<";
+		gui_generic_warning("No selection provided\nSubstituting `Jesus'");
+		key = ">Jesus<";
 	}
-	key = strchr(key,'>');
-	++key;
+	if (buf = strchr(key, '>'))	/* it might not have >< delimiters? */
+		key = buf + 1;
 	keylen = strlen(key);
 	buf = g_new(gchar, keylen);
 	
@@ -379,13 +423,14 @@ gchar *gui_button_press_lookup(GtkWidget * html_widget)
 		if(!len) {
 			return NULL;
 		}
-		
-		
+		//converts encoding from ncr to utf8
+		key = ncr_to_utf8(key);
+
 		buf = main_get_striptext_from_string(settings.MainWindowModule, 
 						key);	
 		
 #ifdef DEBUG
-		g_message(buf);
+		g_message("src/gnome2/html.c: buf=%s",buf);
 #endif
 		if(buf == NULL) return;
 		key = g_strdelimit(buf, ".,\"<>;:?", ' ');
@@ -632,6 +677,8 @@ static struct _info *info_new(GtkHTML * html,
 					   GnomePrintContext * pc,
 					   gdouble * line)
 {
+#ifdef USE_GTKHTML38_3_13
+#else
 	struct _info *info;
 
 	info = g_new(struct _info, 1);
@@ -652,6 +699,7 @@ static struct _info *info_new(GtkHTML * html,
 	info->footer_date = FALSE;
 	info->footer_page_num = TRUE;
 	return info;
+#endif
 }
 
 
@@ -673,6 +721,8 @@ static struct _info *info_new(GtkHTML * html,
 
 void gui_html_print(GtkWidget * htmlwidget, gboolean preview)
 {
+#ifdef USE_GTKHTML38_3_13
+#else
 	GtkHTML *html;
 	GtkWidget *w = NULL;
 	GnomePrintContext *print_context;
@@ -745,4 +795,5 @@ void gui_html_print(GtkWidget * htmlwidget, gboolean preview)
 	}
 
 	g_object_unref(print_master);
+#endif
 }
