@@ -298,7 +298,7 @@ static void on_pinned_tabs_activate(GtkCheckMenuItem * menuitem,
  */
 
 static void on_read_aloud_activate(GtkCheckMenuItem * menuitem,
-				    gpointer user_data)
+				   gpointer user_data)
 {
 	settings.readaloud = menuitem->active;
 	xml_set_value("GnomeSword", "misc", "readaloud",
@@ -332,6 +332,56 @@ static void on_show_verse_numbers_activate(GtkCheckMenuItem * menuitem,
 	main_display_bible(NULL, settings.currentverse);
 }
 
+/******************************************************************************
+ * Name
+ *  on_versehighlight_activate
+ *
+ * Synopsis
+ *   #include "gui/main_menu.h"
+ *
+ *   void on_versehighlight_activate(GtkMenuItem *menuitem, gpointer user_data)	
+ *
+ * Description
+ *   toggle special current verse highlight.
+ *
+ * Return value
+ *   void
+ */
+
+static void on_versehighlight_activate(GtkCheckMenuItem * menuitem,
+				       gpointer user_data)
+{
+	settings.versehighlight = menuitem->active;
+	xml_set_value("GnomeSword", "misc", "versehighlight",
+		      (settings.versehighlight ? "1" : "0"));
+	main_display_bible(NULL, settings.currentverse);
+}
+
+/******************************************************************************
+ * Name
+ *  on_doublespace_activate
+ *
+ * Synopsis
+ *   #include "gui/main_menu.h"
+ *
+ *   void on_doublespace_activate(GtkMenuItem *menuitem, gpointer user_data)	
+ *
+ * Description
+ *   toggle double-spacing of text.
+ *
+ * Return value
+ *   void
+ */
+
+static void on_doublespace_activate(GtkCheckMenuItem * menuitem,
+				    gpointer user_data)
+{
+	settings.doublespace = menuitem->active;
+	xml_set_value("GnomeSword", "misc", "doublespace",
+		      (settings.doublespace ? "1" : "0"));
+	main_display_bible(NULL, settings.currentverse);
+}
+
 /******************************************************************************
  * Name
  *  on_exit_activate
@@ -807,6 +857,20 @@ static GnomeUIInfo view1_menu_uiinfo[] = {
 	 NULL, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, (GdkModifierType) 0, NULL},
+	{
+	 GNOME_APP_UI_TOGGLEITEM, N_("_Highlight Current Verse"),
+	 NULL,
+	 NULL, NULL, NULL,
+	 GNOME_APP_PIXMAP_NONE, NULL,
+	 0, (GdkModifierType) 0, NULL},
+#ifdef DOUBLESPACE
+	{
+	 GNOME_APP_UI_TOGGLEITEM, N_("D_ouble-Space Text"),
+	 NULL,
+	 NULL, NULL, NULL,
+	 GNOME_APP_PIXMAP_NONE, NULL,
+	 0, (GdkModifierType) 0, NULL},
+#endif /* DOUBLESPACE */
 	GNOMEUIINFO_SEPARATOR,
 	{
 	 GNOME_APP_UI_ITEM, N_("_Attach/Detach Sidebar"),
@@ -916,6 +980,10 @@ void gui_create_main_menu(GtkWidget * app)
 	widgets.pinnedtabs_item = view1_menu_uiinfo[8].widget;
 	widgets.readaloud_item = view1_menu_uiinfo[9].widget;
 	widgets.showversenum_item = view1_menu_uiinfo[10].widget;
+	widgets.versehighlight_item = view1_menu_uiinfo[11].widget;
+#ifdef DOUBLESPACE
+	widgets.doublespace_item = view1_menu_uiinfo[12].widget;
+#endif /* DOUBLESPACE */
 	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM
 				       (widgets.versestyle_item),
 				       settings.versestyle);
@@ -928,6 +996,14 @@ void gui_create_main_menu(GtkWidget * app)
 	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM
 				       (widgets.showversenum_item),
 				       settings.showversenum);
+	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM
+				       (widgets.versehighlight_item),
+				       settings.versehighlight);
+#ifdef DOUBLESPACE
+	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM
+				       (widgets.doublespace_item),
+				       settings.doublespace);
+#endif /* DOUBLESPACE */
 	
 	g_signal_connect(GTK_OBJECT(widgets.versestyle_item),
 			   "toggled",
@@ -945,6 +1021,16 @@ void gui_create_main_menu(GtkWidget * app)
 			   "toggled",
 			   G_CALLBACK(on_show_verse_numbers_activate),
 			   NULL);
+	g_signal_connect(GTK_OBJECT(widgets.versehighlight_item),
+			   "toggled",
+			   G_CALLBACK(on_versehighlight_activate),
+			   NULL);
+#ifdef DOUBLESPACE
+	g_signal_connect(GTK_OBJECT(widgets.doublespace_item),
+			   "toggled",
+			   G_CALLBACK(on_doublespace_activate),
+			   NULL);
+#endif /* DOUBLESPACE */
 }
 
 /******************************************************************************
