@@ -57,6 +57,7 @@
 WIDGETS widgets;
 
 
+static gboolean ctrl_key_presed = FALSE;
 static GtkWidget *nav_toolbar;
 /******************************************************************************
  * Name
@@ -203,6 +204,10 @@ void gui_set_bible_comm_layout(void)
 	gtk_paned_set_position(GTK_PANED(widgets.vpaned2),
 				       settings.commpane_hight);
 	
+	if ((settings.showcomms == TRUE)  ||  (settings.showdicts == TRUE)) {
+		gtk_widget_show(widgets.vpaned2);
+	}
+	
 	if (settings.showtexts == FALSE) 
 		gtk_paned_set_position(GTK_PANED(widgets.hpaned), 0);
 	else
@@ -229,8 +234,8 @@ void gui_set_bible_comm_layout(void)
 				       settings.commpane_hight);
 	}
 	
-	if ((settings.showcomms == FALSE)
-		   && (settings.showdicts == FALSE)) {
+	if ((settings.showcomms == FALSE)  && (settings.showdicts == FALSE)) {
+		gtk_widget_hide(widgets.vpaned2);
 		gtk_paned_set_position(GTK_PANED
 				       (widgets.hpaned),
 				       settings.gs_width);	   
@@ -477,6 +482,61 @@ static void on_notebook_comm_book_switch_page(GtkNotebook * notebook,
 			   NULL,
 			   NULL,
 			   settings.comm_showing);
+	if(settings.comm_showing)
+		main_display_commentary(settings.CommWindowModule, settings.currentverse);
+}
+
+
+static
+gboolean on_vbox1_key_press_event(GtkWidget * widget, GdkEventKey * event,
+				  gpointer user_data)
+{
+	switch(event->hardware_keycode) {
+	case 40: //D
+		if(event->state == GDK_MOD1_MASK)  //GDK_CONTROL_MASK) 
+			gtk_widget_grab_focus(widgets.entry_dict);
+		break;
+	case 42: //G
+		if(event->state == GDK_MOD1_MASK)  { //GDK_CONTROL_MASK)  {				
+			gtk_notebook_set_current_page(GTK_NOTEBOOK(widgets.notebook_comm_book),1);
+			gtk_widget_grab_focus(navbar_book.lookup_entry);
+		}
+		break;
+	case 46: //L
+		if(event->state == GDK_CONTROL_MASK)  //GDK_CONTROL_MASK) 
+			gtk_widget_grab_focus(navbar_main.lookup_entry);
+		break;
+	case 41: //F
+		if(event->state == GDK_CONTROL_MASK)  //GDK_CONTROL_MASK) 
+			// bible text only, *sigh*.
+			gui_find_dlg(widgets.html_text,
+				     settings.MainWindowModule,
+				     FALSE, NULL);
+		break;
+	case 54: //C
+		if(event->state == GDK_MOD1_MASK) { //GDK_CONTROL_MASK) {
+			gtk_widget_grab_focus(navbar_main.lookup_entry);
+			gtk_notebook_set_current_page(GTK_NOTEBOOK(widgets.notebook_comm_book),0);
+		}
+		break;
+	case 56: //B
+		if(event->state == GDK_MOD1_MASK)  //GDK_CONTROL_MASK) 
+			gtk_widget_grab_focus(navbar_main.lookup_entry);
+		break;
+	}
+#ifdef DEBUG
+	g_message("on_vbox1_key_press_event\nkeycode: %d",event->hardware_keycode);
+#endif
+	return FALSE;
+}
+
+static
+gboolean on_vbox1_key_release_event(GtkWidget * widget,
+                                        GdkEventKey * event,
+                                        gpointer user_data)
+{
+
+  return FALSE;
 }
 
 
@@ -774,6 +834,15 @@ void create_mainwindow(void)
 
 	gui_install_menu_hints(widgets.app);
 
+
+
+  g_signal_connect ((gpointer) vbox_gs, "key_press_event",
+                    G_CALLBACK (on_vbox1_key_press_event),
+                    NULL);
+  g_signal_connect ((gpointer) vbox_gs, "key_release_event",
+                    G_CALLBACK (on_vbox1_key_release_event),
+                    NULL);
+
 	g_signal_connect(GTK_OBJECT(widgets.notebook_comm_book),
 			   "switch_page",
 			   G_CALLBACK
