@@ -30,6 +30,7 @@
 #include <unistd.h>
 #include <string.h>
 #include <stdio.h>
+#include <errno.h>
 
 #include <bonobo.h>
 #include <gnome.h>
@@ -46,12 +47,18 @@
 #include "main/settings.h"
 #include "main/sword.h"
 #include "main/xml.h"
+#include "main/modulecache.hh"
 
-#define GTK_RESPONSE_INSTALL 303
-#define GTK_RESPONSE_REMOVE 302
 #define GTK_RESPONSE_REFRESH 301
-#define INSTALL 1
-#define REMOVE 0
+#define GTK_RESPONSE_REMOVE  302
+#define GTK_RESPONSE_INSTALL 303
+#define GTK_RESPONSE_ARCHIVE 304
+
+enum {
+	REMOVE  = 0,
+	INSTALL = 1,
+	ARCHIVE = 2,
+};
 
 enum {
 	COLUMN_NAME,
@@ -59,7 +66,9 @@ enum {
 	COLUMN_LOCKED,
 	COLUMN_FIXED,
 	COLUMN_OLD_VERSION,
+	COLUMN_DIFFERENT,
 	COLUMN_NEW_VERSION,
+	COLUMN_DESC,
 	COLUMN_VISIBLE,
 	NUM_COLUMNS
 };
@@ -81,6 +90,7 @@ static GtkWidget *button_cancel;
 static GtkWidget *button1;
 static GtkWidget *button2;
 static GtkWidget *button3;
+static GtkWidget *button4;
 static GtkWidget *label_home;
 static GtkWidget *label_system;
 //static GtkWidget *progressbar;
@@ -111,9 +121,11 @@ static gint current_page;
 static gint response;
 static GdkPixbuf *INSTALLED;
 static GdkPixbuf *LOCKED;
+static GdkPixbuf *REFRESH;
 static GdkPixbuf *BLANK;
 static gchar *current_mod;
-
+static gchar *remote_source;
+static gboolean first_time_user = FALSE;
 
 GladeXML *gxml;
 
@@ -140,6 +152,9 @@ static void create_pixbufs(void)
 					   GTK_ICON_SIZE_MENU, NULL);
 	LOCKED = gdk_pixbuf_new_from_file(PACKAGE_PIXMAPS_DIR
 					  "/epiphany-secure.png", NULL);
+	REFRESH = gtk_widget_render_icon(dialog,
+					 GTK_STOCK_REFRESH,
+					 GTK_ICON_SIZE_MENU, NULL);
 	BLANK = gtk_widget_render_icon(dialog,
 				       "gnome-stock-blank",
 				       GTK_ICON_SIZE_MENU, NULL);
@@ -170,12 +185,12 @@ static gboolean mod_mgr_check_for_file(const gchar * filename)
 
 /******************************************************************************
  * Name
- *   install_modules
+ *   remove_install_modules
  *
  * Synopsis
  *   #include "gui/mod_mgr.h"
  *
- *    void install_modules(GList * modules)
+ *    void remove_install_modules(GList * modules, int activity)
  *
  * Description
  *   
@@ -184,7 +199,9 @@ static gboolean mod_mgr_check_for_file(const gchar * filename)
  *   void
  */
 
-static void remove_install_modules(GList * modules, gboolean install)
+#define ZIP_DIR	".sword/zip"
+
+static void remove_install_modules(GList * modules, int activity)
 {
 	GList *tmp = NULL;
 	gchar *buf;
@@ -207,16 +224,15 @@ static void remove_install_modules(GList * modules, gboolean install)
 	mods = g_string_truncate(mods, mods->len - 2);
 	yes_no_dialog = gui_new_dialog();
 	yes_no_dialog->stock_icon = GTK_STOCK_DIALOG_QUESTION;
-	if (install)
-		g_string_printf(dialog_text,
-				"<span weight=\"bold\">%s</span>\n\n%s",
-				_("Install the following modules:"),
-				mods->str);
-	else
-		g_string_printf(dialog_text,
-				"<span weight=\"bold\">%s</span>\n\n%s",
-				_("Remove the following modules:"),
-				mods->str);
+
+	g_string_printf(dialog_text,
+			"<span weight=\"bold\">%s</span>\n\n%s",
+			((activity == INSTALL)
+			 ? _("Install these modules:")
+			 : ((activity == REMOVE)
+			    ? _("Remove these modules:")
+			    : _("Archive these modules:"))),
+			mods->str);
 
 	yes_no_dialog->label_top = dialog_text->str;
 	yes_no_dialog->yes = TRUE;
@@ -235,12 +251,12 @@ static void remove_install_modules(GList * modules, gboolean install)
 		g_string_free(dialog_text, TRUE);
 		return;
 	}
-	if(install)
-		gtk_progress_bar_set_text(GTK_PROGRESS_BAR(progressbar_refresh),
-						  _("Preparing to install"));
-	else
-		gtk_progress_bar_set_text(GTK_PROGRESS_BAR(progressbar_refresh),
-						  _("Preparing to remove"));
+	gtk_progress_bar_set_text(GTK_PROGRESS_BAR(progressbar_refresh),
+				  ((activity == INSTALL)
+				   ? _("Preparing to install")
+				   : ((activity == REMOVE)
+				      ? _("Preparing to remove")
+				      : _("Preparing to archive"))));
 	gtk_widget_show(progressbar_refresh);	
 	while (gtk_events_pending()) {
 		gtk_main_iteration();
@@ -252,6 +268,7 @@ static void remove_install_modules(GList * modules, gboolean install)
 	gtk_widget_hide(button1);
 	gtk_widget_hide(button2);
 	gtk_widget_hide(button3);
+	gtk_widget_hide(button4);
 	gtk_widget_show(button_cancel);
 	while (gtk_events_pending()) {
 		gtk_main_iteration();
@@ -261,20 +278,84 @@ static void remove_install_modules(GList * modules, gboolean install)
 	while (tmp) {
 		buf = (gchar *) tmp->data;
 		current_mod = buf;
-		if (install) {
-			g_string_printf(mods, "%s: %s",
-					_("Installing: "), buf);
-			gtk_progress_bar_set_text(GTK_PROGRESS_BAR
-						  (progressbar_refresh),
-						  mods->str);
-		} else {
-			g_string_printf(mods, "%s: %s", _("Removing: "),
-					buf);
-			gtk_progress_bar_set_text(GTK_PROGRESS_BAR
-						  (progressbar_refresh),
-						  mods->str);
-			g_print("uninstalling %s from %s\n", buf,
-				destination);
+		g_string_printf(mods, "%s: %s",
+				((activity == INSTALL)
+				 ? _("Installing")
+				 : ((activity == REMOVE)
+				    ? _("Removing")
+				    : _("Archiving"))),
+				buf);
+		gtk_progress_bar_set_text(GTK_PROGRESS_BAR
+					  (progressbar_refresh),
+					  mods->str);
+
+		if (activity == ARCHIVE) {
+			GString *cmd = g_string_new(NULL);
+			gchar *dir = g_new(char, strlen(settings.homedir) +
+					   strlen(ZIP_DIR) + 2);
+			gchar *zipfile;
+			char *datapath, *conf_file;
+			FILE *result;
+
+#ifdef DEBUG
+			g_print("archive %s in %s\n", buf, destination);
+#endif
+			sprintf(dir, "%s/%s", settings.homedir, ZIP_DIR);
+			if ((access(dir, F_OK) == -1) &&
+			    (mkdir(dir, S_IRWXU) != 0)) {
+				char msg[300];
+				sprintf(msg, _("`mkdir %s' failed:\n%s."),
+					dir, strerror(errno));
+				g_free(dir);
+				gui_generic_warning(msg);
+				return;
+			}
+
+			zipfile = g_new(char, strlen(dir) + 100); // excess
+			sprintf(zipfile, "%s/%s.zip", dir, buf);
+			datapath = main_get_mod_config_entry(buf, "DataPath");
+			if (access(datapath, F_OK) == -1)
+			    *(strrchr(datapath, '/')) = '\0';
+
+			conf_file = main_get_mod_config_file(buf, destination);
+			g_string_printf(cmd,
+				"( rm -f '%s' && cd '%s' && zip -r '%s' 'mods.d/%s' '%s' ) 2>&1",
+				zipfile,
+				destination,
+				zipfile,
+				conf_file,
+				datapath);
+			g_free(conf_file);
+			g_free(datapath);
+			
+			if ((result = popen(cmd->str, "r")) == NULL) {
+				gui_generic_warning
+				    (_("GnomeSword could not execute archiver"));
+			} else {
+				gchar output[258];
+				g_string_truncate(cmd, 0);
+				g_string_append(cmd, buf);
+				g_string_append(cmd, _(" archival result:\n\n"));
+				while (fgets(output, 256, result) != NULL)
+					g_string_append(cmd, output);
+				pclose(result);
+				g_string_append(cmd, _("\nArchive in "));
+				g_string_append(cmd, zipfile);
+				gui_generic_warning(cmd->str);
+			}
+			g_free(zipfile);
+			g_free(dir);
+			g_string_free(cmd, TRUE);
+			failed = 0;
+		}
+
+		if ((activity == REMOVE) ||	// just delete it
+		    (!first_time_user &&	// don't trip on "no modules".
+		     (activity == INSTALL) &&
+		     main_is_module(buf))) {	// delete before re-install
+#ifdef DEBUG
+			g_print("remove %s from %s\n", buf, destination);
+#endif
 			failed = mod_mgr_uninstall(destination, buf);
 			if (failed == -1) {
 				//mod_mgr_shut_down();
@@ -285,18 +366,24 @@ static void remove_install_modules(GList * modules, gboolean install)
 					    (GTK_LABEL(label_home));
 					g_warning(new_dest);
 				}
-				g_print("uninstalling %s from %s\n",
+				g_print("removing %s from %s\n",
 					buf, new_dest);
 				failed =
 				    mod_mgr_uninstall(new_dest, buf);
 			}
 
+			// annihilate cache of removed module.
+			ModuleCacheErase((const char *)buf);
+
 			while (gtk_events_pending()) {
 				gtk_main_iteration();
 			}
 		}
-		if (install) {
-			g_print("installing %s\n", buf);
+
+		if (activity == INSTALL) {
+#ifdef DEBUG
+			g_print("install %s, source=%s\n", buf,source);
+#endif
 			if (local)
 				failed =
 				    mod_mgr_local_install_module(source, buf);
@@ -310,11 +397,12 @@ static void remove_install_modules(GList * modules, gboolean install)
 	have_changes = TRUE;
 	g_list_free(tmp);
 	if (failed) {
-		if (install)
-			g_string_printf(mods, "%s",
-					_("Install failed"));
-		else
-			g_string_printf(mods, "%s", _("Remove failed"));
+		g_string_printf(mods, "%s failed",
+				((activity == INSTALL)
+				 ? _("Install")
+				 : ((activity == REMOVE)
+				    ? _("Remove")
+				    : _("Archive"))));
 	} else {
 		g_string_printf(mods, "%s", _("Finished"));		
 	}
@@ -330,6 +418,7 @@ static void remove_install_modules(GList * modules, gboolean install)
 		break;
 		case 4:
 			gtk_widget_show(button3);
+			gtk_widget_show(button4);
 		break;		
 	}
 }
@@ -397,7 +486,7 @@ static GList *parse_treeview(GList * list, GtkTreeModel * model,
  *   void
  */
 
-static GList *get_list_mods_to_remove_install(gboolean install)
+static GList *get_list_mods_to_remove_install(int activity)
 {
 	GList *retval = NULL;
 	GtkTreeIter root;
@@ -405,7 +494,7 @@ static GList *get_list_mods_to_remove_install(gboolean install)
 	GtkTreeModel *model;
 	gchar *name;
 	gboolean fixed;
-	if (install)
+	if (activity == INSTALL)
 		model =
 		    gtk_tree_view_get_model(GTK_TREE_VIEW(treeview));
 	else
@@ -414,8 +503,8 @@ static GList *get_list_mods_to_remove_install(gboolean install)
 	if (!gtk_tree_model_get_iter_first
 	    (GTK_TREE_MODEL(model), &root))
 		return retval;
-	if (!gtk_tree_model_iter_has_child(model, &root))
-		return retval;
+	/*if (!gtk_tree_model_iter_has_child(model, &root))
+		return retval;*/
 
 	do {
 		gtk_tree_model_get(model, &root,
@@ -464,11 +553,27 @@ static void add_module_to_language_folder(GtkTreeModel * model,
 	gboolean valid;
 	GdkPixbuf *installed;
 	GdkPixbuf *locked;
-	GString *str = g_string_new(NULL);
+	GdkPixbuf *refresh;
+	gchar *description = NULL;
+	gsize bytes_read;
+	gsize bytes_written;
+	GError *error = NULL;
+	gchar *buf;
 
-	if ((!g_ascii_isalnum(info->language[0]))
-	    || (info->language == NULL))
-		info->language = N_("Unknown");
+	/* Check language */
+	buf = strdup(info->language);
+	if (!g_utf8_validate(buf,-1,NULL))
+		info->language = _("Unknown");
+	if (!g_unichar_isalnum(g_utf8_get_char(buf)) || (info->language == NULL))
+		info->language = _("Unknown");
+	g_free(buf);
+
+	description = g_convert(info->description, -1, UTF_8, OLD_CODESET, &bytes_read,
+			 &bytes_written, &error);
+	if(description == NULL) {
+		g_print ("error: %s\n", error->message);
+		g_error_free (error);
+	}
 
 	valid = gtk_tree_model_iter_children(model, &iter_iter, &iter);
 	while (valid) {
@@ -479,25 +584,39 @@ static void add_module_to_language_folder(GtkTreeModel * model,
 				   &str_data, -1);
 		if (!strcmp(info->language, str_data)) {
 			if (info->installed)
-				installed = INSTALLED;	//g_string_printf(str, "*%s", info->name);
+				installed = INSTALLED;
 			else
-				installed = BLANK;	//g_string_printf(str, "%s", info->name);
+				installed = BLANK;
+
 			if (info->locked)
 				locked = LOCKED;
 			else
 				locked = BLANK;
+
+			if (info->installed &&
+			    (!info->old_version && info->new_version &&
+			     strcmp(info->new_version, " ")) ||
+			    (info->old_version && !info->new_version) ||
+			    (info->old_version && info->new_version &&
+			     strcmp(info->old_version, info->new_version)))
+				refresh = REFRESH;
+			else
+				refresh = BLANK;
+
 			gtk_tree_store_append(GTK_TREE_STORE(model),
 					      &child_iter, &iter_iter);
-			gtk_tree_store_set(GTK_TREE_STORE(model), &child_iter, COLUMN_NAME, info->name,	//str->str,
+			gtk_tree_store_set(GTK_TREE_STORE(model), &child_iter,
+					   COLUMN_NAME, info->name,
 					   COLUMN_INSTALLED, installed,
 					   COLUMN_LOCKED, locked,
 					   COLUMN_FIXED, FALSE,
 					   COLUMN_OLD_VERSION,
 					   info->old_version,
+					   COLUMN_DIFFERENT, refresh,
 					   COLUMN_NEW_VERSION,
 					   info->new_version,
+					   COLUMN_DESC, description,
 					   COLUMN_VISIBLE, TRUE, -1);
-
 			g_free(str_data);
 			return;
 		}
@@ -525,32 +644,30 @@ static void add_module_to_language_folder(GtkTreeModel * model,
  */
 
 static void add_language_folder(GtkTreeModel * model, GtkTreeIter iter,
-				const gchar * language)
+				const gchar *language)
 {
 	GtkTreeIter iter_iter;
 	GtkTreeIter parent;
 	GtkTreeIter child_iter;
-	gchar *buf;
 	gsize bytes_read;
 	gsize bytes_written;
 	GError *error = NULL;
 	gboolean valid;
+	gchar *buf;
 
-		
-	if ((!g_ascii_isalnum(language[0])) || (language == NULL))
-		language = N_("Unknown");
+	/* Check language */
+	buf = strdup(language);
+	if (!g_utf8_validate(buf,-1,NULL))
+		language = _("Unknown");
+	if (!g_unichar_isalnum(g_utf8_get_char(buf)) || (language == NULL))
+		language = _("Unknown");
 
 	valid = gtk_tree_model_iter_children(model, &iter_iter, &iter);
 	while (valid) {
 		/* Walk through the list, reading each row */
 		gchar *str_data;
-		buf = g_convert(language, 
-				-1, 
-				UTF_8, 
-				OLD_CODESET, 
-				&bytes_read,
-				&bytes_written, 
-				&error);
+
+		buf = strdup(language);
 		if(buf == NULL) {
 			g_print ("error: %s\n", error->message);
 			g_error_free (error);
@@ -562,7 +679,7 @@ static void add_language_folder(GtkTreeModel * model, GtkTreeIter iter,
 				COLUMN_NAME, 
 				&str_data, 
 				-1);
-		
+
 		if(!g_utf8_collate(g_utf8_casefold(buf,-1),
 				      g_utf8_casefold(str_data,-1))) {
 		/*if(!strcmp(buf,str_data)) {*/
@@ -575,13 +692,15 @@ static void add_language_folder(GtkTreeModel * model, GtkTreeIter iter,
 		valid = gtk_tree_model_iter_next(model, &iter_iter);
 	}
 	gtk_tree_store_append(GTK_TREE_STORE(model), &child_iter, &iter);
-	buf = g_convert(language, 
-			-1, 
-			UTF_8, 
-			OLD_CODESET, 
-			&bytes_read,
-			&bytes_written, 
-			&error);
+//	buf = g_convert(language, 
+//			-1, 
+//			UTF_8, 
+//			OLD_CODESET, 
+//			&bytes_read,
+//			&bytes_written, 
+//			&error);
+	buf = strdup(language); 
+
 	gtk_tree_store_set(GTK_TREE_STORE(model), 
 			&child_iter,
 			COLUMN_VISIBLE, 
@@ -657,7 +776,7 @@ static void load_module_tree(GtkTreeView * treeview, gboolean install)
 		return;
 	tmp2 = tmp;
 
-	/*  add lBiblical Texts folder */
+	/*  add Biblical Texts folder */
 	gtk_tree_store_append(store, &text, NULL);
 	gtk_tree_store_set(store, &text, 0, _("Biblical Texts"), -1);
 
@@ -700,6 +819,7 @@ static void load_module_tree(GtkTreeView * treeview, gboolean install)
 
 	while (tmp) {
 		info = (MOD_MGR *) tmp->data;
+		
 		if (!strcmp(info->type, TEXT_MODS)) {
 			add_module_to_language_folder(GTK_TREE_MODEL
 						      (store), text,
@@ -730,6 +850,36 @@ static void load_module_tree(GtkTreeView * treeview, gboolean install)
 }
 
 
+/******************************************************************************
+ * Name
+ *   remove_install_wrapper
+ *
+ * Synopsis
+ *   #include "gui/mod_mgr.h"
+ *
+ *    void remove_install_wrapper(GList * modules)
+ *
+ * Description
+ *   generalization of install/remove/archive methodology.
+ *
+ * Return value
+ *   void
+ */
+
+static void remove_install_wrapper(int activity)
+{
+	GList *modules = NULL;
+	modules = get_list_mods_to_remove_install(activity);
+	while (gtk_events_pending()) {
+		gtk_main_iteration();
+	}
+	remove_install_modules(modules, activity);
+	load_module_tree(GTK_TREE_VIEW(treeview), (activity == INSTALL));
+	while (gtk_events_pending()) {
+		gtk_main_iteration();
+	} 	
+}
+
 /******************************************************************************
  * Name
  *   response_refresh
@@ -749,18 +899,21 @@ static void load_module_tree(GtkTreeView * treeview, gboolean install)
 static void response_refresh(void)
 {
 	gint failed = 1;
+	gchar *buf = NULL;
 	
-	gtk_progress_bar_set_text(GTK_PROGRESS_BAR(progressbar_refresh), 
-					_("Refreshing remote"));
+	buf = g_strdup_printf("%s: %s", _("Refreshing remote"),remote_source);
+	gtk_progress_bar_set_text(GTK_PROGRESS_BAR(progressbar_refresh), buf);
 	gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(progressbar_refresh), 0);
 	gtk_widget_show(progressbar_refresh);	
 	while (gtk_events_pending()) {
 		gtk_main_iteration();
 	}	
+	failed = mod_mgr_refresh_remote_source(remote_source);
+	
+	/*failed =
+		mod_mgr_refresh_remote_source(
+		  gtk_entry_get_text(GTK_ENTRY(GTK_BIN(combo_entry2)->child)));*/
 	
-	failed =
-	    mod_mgr_refresh_remote_source(
-	    	gtk_entry_get_text(GTK_ENTRY(GTK_BIN(combo_entry2)->child)));
 	if (failed) {
 		gtk_progress_bar_set_text(
 			GTK_PROGRESS_BAR(progressbar_refresh), _("Remote not found"));
@@ -775,7 +928,9 @@ static void response_refresh(void)
 		gtk_widget_hide(button1);
 		gtk_widget_show(button2);
 		gtk_widget_hide(button3);
+		gtk_widget_hide(button4);
 	}
+	g_free(buf);
 }
 
 /******************************************************************************
@@ -801,8 +956,13 @@ static void response_close(void)
 		
 		gtk_widget_destroy(GTK_WIDGET(dialog));
 		g_string_printf(str, "%s/dirlist", settings.homedir);
-		if (mod_mgr_check_for_file(str->str))
+		if (mod_mgr_check_for_file(str->str)) {
+#ifdef DEBUG
 			g_warning(str->str);
+#else
+			unlink(str->str);
+#endif
+		}
 		g_string_free(str,TRUE);
 	}
 }
@@ -878,6 +1038,11 @@ static void add_columns(GtkTreeView * treeview, gboolean remove)
 						     renderer, "text",
 						     COLUMN_NAME, NULL);
 	gtk_tree_view_column_set_sort_column_id(column, COLUMN_NAME);
+	/* set this column to a fixed sizing (of 185 pixels) */
+	gtk_tree_view_column_set_sizing(GTK_TREE_VIEW_COLUMN(column),
+					GTK_TREE_VIEW_COLUMN_FIXED);
+	gtk_tree_view_column_set_fixed_width(GTK_TREE_VIEW_COLUMN
+					     (column), 185);	
 	gtk_tree_view_append_column(treeview, column);
 
 	column = gtk_tree_view_column_new();
@@ -962,6 +1127,19 @@ static void add_columns(GtkTreeView * treeview, gboolean remove)
 	if (remove)
 		return;
 
+	/* column for refresh/update */
+	column = gtk_tree_view_column_new();
+	image = gtk_image_new_from_stock(GTK_STOCK_REFRESH,
+					 GTK_ICON_SIZE_MENU);
+	gtk_widget_show(image);
+	renderer = GTK_CELL_RENDERER(gtk_cell_renderer_pixbuf_new());
+	gtk_tree_view_column_set_widget(column, image);
+	gtk_tree_view_column_pack_start(column, renderer, TRUE);
+	gtk_tree_view_column_set_attributes(column, renderer,
+					    "pixbuf", COLUMN_DIFFERENT,
+					    NULL);
+	gtk_tree_view_append_column(treeview, column);
+
 	/* column for source module version */
 	renderer = gtk_cell_renderer_text_new();
 	column =
@@ -972,6 +1150,17 @@ static void add_columns(GtkTreeView * treeview, gboolean remove)
 	/*gtk_tree_view_column_set_sort_column_id(column,
 	   COLUMN_NEW_VERSION); */
 	gtk_tree_view_append_column(treeview, column);
+
+	/* column for description */
+	renderer = gtk_cell_renderer_text_new();
+	column =
+	    gtk_tree_view_column_new_with_attributes(_("Description"),
+						     renderer, "text",
+						     COLUMN_DESC,
+						     NULL);
+	/*gtk_tree_view_column_set_sort_column_id(column,
+	   COLUMN_DESC); */
+	gtk_tree_view_append_column(treeview, column);
 }
 
 
@@ -1092,7 +1281,7 @@ static GtkTreeModel *create_model_to_first(void)
 	gtk_tree_store_append(model, &child_iter, &iter);
 	gtk_tree_store_set(model, &child_iter, 0, _("Install"), 1, 3, -1);
 	gtk_tree_store_append(model, &child_iter, &iter);
-	gtk_tree_store_set(model, &child_iter, 0, _("Remove"), 1, 4, -1);
+	gtk_tree_store_set(model, &child_iter, 0, _("Remove/Archive"), 1, 4, -1);
 
 	return GTK_TREE_MODEL(model);
 }
@@ -1128,6 +1317,8 @@ static GtkTreeModel *create_model(void)
 				   GDK_TYPE_PIXBUF,
 				   G_TYPE_BOOLEAN,
 				   G_TYPE_STRING,
+				   GDK_TYPE_PIXBUF,
+				   G_TYPE_STRING,
 				   G_TYPE_STRING, G_TYPE_BOOLEAN);
 	return GTK_TREE_MODEL(store);
 }
@@ -1295,7 +1486,9 @@ void on_notebook1_switch_page(GtkNotebook * notebook,
 		clear_and_hide_progress_bar();
 		break;
 	case 1:
-		clear_and_hide_progress_bar();		
+		clear_and_hide_progress_bar();	
+		mod_mgr_shut_down();
+		mod_mgr_init(destination);	
 		break;
 	case 2:
 		clear_and_hide_progress_bar();
@@ -1309,8 +1502,7 @@ void on_notebook1_switch_page(GtkNotebook * notebook,
 			g_string_printf(str,
 					"<span weight=\"bold\">%s</span>\n\n%s",
 					_("Please Refresh"),
-					_
-					("Your module list is not up to date!"));
+					_("Your module list is not up to date!"));
 			yes_no_dialog->label_top = str->str;
 			yes_no_dialog->ok = TRUE;
 
@@ -1372,7 +1564,9 @@ void on_radiobutton2_toggled(GtkToggleButton * togglebutton,
 {
 	if (togglebutton->active) {
 		gtk_widget_show(button1);
-		//gtk_widget_show(progressbar_refresh);
+		if(remote_source)
+		        g_free(remote_source);
+		remote_source = g_strdup(gtk_combo_box_get_active_text(GTK_COMBO_BOX(combo_entry2)));
 	} else {
 		gtk_widget_hide(button1);
 		gtk_widget_hide(progressbar_refresh);
@@ -1581,6 +1775,11 @@ void on_dialog_destroy(GtkObject * object, gpointer user_data)
 #ifdef DEBUG
 	g_message("on_destroy");
 #endif
+	if(remote_source) {
+	        g_free(remote_source);
+		remote_source = NULL;
+	}
+	
 	mod_mgr_shut_down();
 	while (gtk_events_pending()) {
 		gtk_main_iteration();
@@ -1599,24 +1798,17 @@ void on_refresh_clicked(GtkButton * button, gpointer  user_data)
 
 void on_install_clicked(GtkButton * button, gpointer  user_data)
 {
-	GList *modules = NULL;
-	modules = get_list_mods_to_remove_install(INSTALL);
-	while (gtk_events_pending()) {
-		gtk_main_iteration();
-	}
-	remove_install_modules(modules, INSTALL);
-	load_module_tree(GTK_TREE_VIEW(treeview), TRUE);
-	while (gtk_events_pending()) {
-		gtk_main_iteration();
-	} 	
+	remove_install_wrapper(INSTALL);
 }
 
 void on_remove_clicked(GtkButton * button, gpointer  user_data)
 {
-	GList *modules = NULL;
-	modules = get_list_mods_to_remove_install(REMOVE);
-	remove_install_modules(modules, REMOVE);
-	load_module_tree(GTK_TREE_VIEW(treeview2), FALSE);	
+	remove_install_wrapper(REMOVE);
+}
+
+void on_archive_clicked(GtkButton * button, gpointer  user_data)
+{
+	remove_install_wrapper(ARCHIVE);
 }
 
 void on_cancel_clicked(GtkButton * button, gpointer  user_data)
@@ -1640,8 +1832,9 @@ void on_cancel_clicked(GtkButton * button, gpointer  user_data)
  * Description
  *   these are local defines
  *   GTK_RESPONSE_REFRESH = 301
- *   GTK_RESPONSE_INSTALL = 303
  *   GTK_RESPONSE_REMOVE  = 302
+ *   GTK_RESPONSE_INSTALL = 303
+ *   GTK_RESPONSE_ARCHIVE = 304
  *
  * Return value
  *   void
@@ -1665,20 +1858,13 @@ void on_mod_mgr_response(GtkDialog * dialog, gint response_id, gpointer user_dat
 		response_close();
 		break;
 	case GTK_RESPONSE_INSTALL:
-		modules = get_list_mods_to_remove_install(INSTALL);
-		while (gtk_events_pending()) {
-			gtk_main_iteration();
-		}
-		remove_install_modules(modules, INSTALL);
-		load_module_tree(GTK_TREE_VIEW(treeview), TRUE);
-		while (gtk_events_pending()) {
-			gtk_main_iteration();
-		}
+		remove_install_wrapper(INSTALL);
 		break;
 	case GTK_RESPONSE_REMOVE:
-		modules = get_list_mods_to_remove_install(REMOVE);
-		remove_install_modules(modules, REMOVE);
-		load_module_tree(GTK_TREE_VIEW(treeview2), FALSE);
+		remove_install_wrapper(REMOVE);
+		break;
+	case GTK_RESPONSE_ARCHIVE:
+		remove_install_wrapper(ARCHIVE);
 		break;
 	}
 }
@@ -1704,6 +1890,7 @@ void on_button5_clicked(GtkButton * button, gpointer  user_data)
 {
 	GtkWidget *dlg = create_fileselection_local_source();
 	gtk_widget_show(dlg);
+	gtk_dialog_run(GTK_DIALOG(dlg));
 }
 
 
@@ -1752,7 +1939,7 @@ void on_button6_clicked(GtkButton * button, gpointer user_data)
 
 	yes_no_dialog = gui_new_dialog();
 	yes_no_dialog->stock_icon = GTK_STOCK_DIALOG_WARNING;
-	yes_no_dialog->title = N_("Bookmark");
+	yes_no_dialog->title = _("Bookmark");
 	g_string_printf(str,
 			"<span weight=\"bold\">%s</span>\n\n%s|%s|%s|%s",
 			_("Remove the selected source"),
@@ -1798,7 +1985,10 @@ void on_button7_clicked(GtkButton * button, gpointer user_data)
 	GS_DIALOG *dialog;
 	GtkTreeIter iter;
 	GString *str = g_string_new(NULL);
-
+	
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radiobutton2),TRUE);
+	gtk_widget_hide(button1);
+	
 	GtkTreeModel *model =
 	    gtk_tree_view_get_model(GTK_TREE_VIEW(treeview_remote));
 	g_string_printf(str,
@@ -1807,10 +1997,10 @@ void on_button7_clicked(GtkButton * button, gpointer user_data)
 	dialog = gui_new_dialog();
 	dialog->stock_icon = GTK_STOCK_DIALOG_INFO;
 	dialog->label_top = str->str;
-	dialog->label1 = N_("Caption:");
-	dialog->label2 = N_("Type:");
-	dialog->label3 = N_("URL:");
-	dialog->label4 = N_("Directory:");
+	dialog->label1 = _("Caption:");
+	dialog->label2 = _("Type:");
+	dialog->label3 = _("URL:");
+	dialog->label4 = _("Directory:");
 	dialog->text1 = g_strdup("Crosswire");
 	dialog->text2 = g_strdup("FTP");
 	dialog->text3 = g_strdup("ftp.crosswire.org");
@@ -1834,13 +2024,24 @@ void on_button7_clicked(GtkButton * button, gpointer user_data)
 			   COLUMN_CAPTION, dialog->text1,
 			   COLUMN_SOURCE, dialog->text3,
 			   COLUMN_DIRECTORY, dialog->text4, -1);
+	
+	if(remote_source)
+	        g_free(remote_source);
+	remote_source = g_strdup(dialog->text1);
+	
 	g_free(dialog->text1);
 	g_free(dialog->text2);
 	g_free(dialog->text3);
 	g_free(dialog->text4);
 	g_free(dialog);
 	g_string_free(str, TRUE);
-	save_sources();
+	save_sources();	
+	while (gtk_events_pending()) {
+		gtk_main_iteration();
+	}	
+	mod_mgr_shut_down();
+	mod_mgr_init(destination);
+	
 }
 
 
@@ -1889,7 +2090,7 @@ void on_button8_clicked(GtkButton * button, gpointer user_data)
 
 	yes_no_dialog = gui_new_dialog();
 	yes_no_dialog->stock_icon = GTK_STOCK_DIALOG_WARNING;
-	yes_no_dialog->title = N_("Bookmark");
+	yes_no_dialog->title = _("Bookmark");
 	g_string_printf(str,
 			"<span weight=\"bold\">%s</span>\n\n%s|%s|%s|%s",
 			_("Remove the selected source"),
@@ -1958,11 +2159,13 @@ gboolean on_treeview1_button_release_event(GtkWidget * widget,
 					gtk_widget_hide(button1);
 				gtk_widget_hide(button2);
 				gtk_widget_hide(button3);
+				gtk_widget_hide(button4);
 				break;
 			case 2:
 				gtk_widget_hide(button1);
 				gtk_widget_hide(button2);
 				gtk_widget_hide(button3);
+				gtk_widget_hide(button4);
 				break;
 			case 3:
 				if (GTK_TOGGLE_BUTTON(radiobutton2)->
@@ -1972,9 +2175,11 @@ gboolean on_treeview1_button_release_event(GtkWidget * widget,
 					gtk_widget_hide(button1);
 				gtk_widget_show(button2);
 				gtk_widget_hide(button3);
+				gtk_widget_hide(button4);
 				break;
 			case 4:
 				gtk_widget_show(button3);
+				gtk_widget_show(button4);
 				gtk_widget_hide(button1);
 				gtk_widget_hide(button2);
 				break;
@@ -2108,6 +2313,14 @@ void setup_dialog_action_area(GtkDialog * dialog)
 	g_signal_connect(button3, "clicked", G_CALLBACK(on_remove_clicked), NULL);
 	//gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button3, 302);
 	//GTK_WIDGET_SET_FLAGS (button3, GTK_CAN_DEFAULT);
+
+/* archive */	
+	button4 =  gtk_button_new_from_stock ("gtk-save");
+	gtk_box_pack_start(GTK_BOX(dialog_action_area1),button4,FALSE, FALSE,0);
+	g_signal_connect(button3, "clicked", G_CALLBACK(on_archive_clicked), NULL);
+	//gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button4, 304);
+	//GTK_WIDGET_SET_FLAGS (button4, GTK_CAN_DEFAULT);
+
 /* cancel */	
 	button_cancel =  gtk_button_new_from_stock ("gtk-cancel");
 	gtk_box_pack_start(GTK_BOX(dialog_action_area1),button_cancel,FALSE, FALSE,0);
@@ -2156,6 +2369,15 @@ static void setup_ui_labels()
 	g_free(path);
 }
 
+
+static void
+on_comboboxentry_remote_changed(GtkComboBox *combobox, gpointer user_data)
+{
+	if(remote_source)
+		g_free(remote_source);
+	remote_source = g_strdup(gtk_entry_get_text(GTK_ENTRY(GTK_BIN(combobox)->child)));
+}
+
 static
 GtkWidget *create_module_manager_dialog(gboolean first_run)
 {
@@ -2212,6 +2434,7 @@ GtkWidget *create_module_manager_dialog(gboolean first_run)
 		button1 = glade_xml_get_widget (gxml, "button2"); /* refresh */
 		button2 = glade_xml_get_widget (gxml, "button3"); /* install */
 		button3 = glade_xml_get_widget (gxml, "button9"); /* remove */
+		button4 = glade_xml_get_widget (gxml, "button13"); /* archive */
 	}
 		
 	g_signal_connect(dialog, "response",
@@ -2267,6 +2490,9 @@ GtkWidget *create_module_manager_dialog(gboolean first_run)
 	set_combobox(GTK_COMBO_BOX(combo_entry1));
 	combo_entry2 = glade_xml_get_widget (gxml, "comboboxentry2"); /* remote source */
 	set_combobox(GTK_COMBO_BOX(combo_entry2));
+	g_signal_connect ((gpointer) combo_entry2, "changed",
+                    G_CALLBACK (on_comboboxentry_remote_changed),
+                    NULL);
 	/* radio buttons */
 	radiobutton_source = glade_xml_get_widget (gxml, "radiobutton1"); /* local */
 	radiobutton2 = glade_xml_get_widget (gxml, "radiobutton2"); /* remote */
@@ -2338,9 +2564,11 @@ void gui_open_mod_mgr_initial_run(void)
 	//if (!lang) lang="C";
 	//main_module_mgr_set_sword_locale(lang);
 	//OLD_CODESET = "iso8859-1";
+	first_time_user = TRUE;
 	dlg = create_module_manager_dialog(TRUE);
 	gtk_dialog_run((GtkDialog *) dlg);
 	gtk_widget_destroy(dlg);
+	first_time_user = FALSE;
 }
 
 /******************************************************************************
