@@ -61,6 +61,8 @@ typedef enum {
 	USE_PINNED_TABS,
 	READ_ALOUD,
 	SHOW_VERSE_NUM,
+	VERSE_HIGHLIGHT,
+	DOUBLE_SPACE,
 	SHOW_SPLASH_SCREEN,
 	SHOW_BIBLE_PANE,
 	SHOW_COMMENTARY_PANE,
@@ -79,7 +81,9 @@ typedef enum {
 	TEXT_BACKGROUND,
 	TEXT_CURRENT_VERSE,
 	VERSE_NUMBERS,
-	HREF_LINKS
+	HREF_LINKS,
+	HIGHLIGHT_FG,
+	HIGHLIGHT_BG
 } which_color_combo;
 
 
@@ -132,6 +136,8 @@ struct _preferences_color_pickers {
 	GtkWidget *text_current_verse;
 	GtkWidget *verse_numbers;
 	GtkWidget *href_links;
+	GtkWidget *highlight_fg;
+	GtkWidget *highlight_bg;
 };
 
 typedef struct _preferences_check_buttons CHECK_BUTTONS;
@@ -151,6 +157,8 @@ struct _preferences_check_buttons {
 	GtkWidget *use_imageresize;
 	GtkWidget *readaloud;
 	GtkWidget *show_verse_num;
+	GtkWidget *versehighlight;
+	GtkWidget *doublespace;
 	GtkWidget *show_splash_screen;
 
 	GtkWidget *show_bible_pane;
@@ -459,6 +467,72 @@ void on_colorbutton5_color_set(GtkColorButton * colorbutton,
 	apply_color_settings();
 }
 
+/******************************************************************************
+ * Name
+ *   on_colorbutton6_color_set
+ *
+ * Synopsis
+ *   #include "preferences_dialog.h"
+ *
+ *   void on_colorbutton6_color_set(GtkColorButton  * colorbutton, 
+ *							gpointer user_data)
+ *
+ * Description
+ *   
+ *   
+ *
+ * Return value
+ *   void
+ */
+
+void on_colorbutton6_color_set(GtkColorButton * colorbutton,
+                                       			 gpointer user_data)
+{
+	gchar *buf2 = NULL;
+ 	GdkColor color;
+	
+	gtk_color_button_get_color(colorbutton, &color);
+	buf2 = gdkcolor_to_hex(color,1); 
+	xml_set_value("GnomeSword", "HTMLcolors", "highlight_fg", buf2);
+	settings.highlight_fg = xml_get_value("HTMLcolors", "highlight_fg");
+	if (buf2)
+		g_free(buf2);
+	apply_color_settings();
+}
+
+/******************************************************************************
+ * Name
+ *   on_colorbutton7_color_set
+ *
+ * Synopsis
+ *   #include "preferences_dialog.h"
+ *
+ *   void on_colorbutton7_color_set(GtkColorButton  * colorbutton, 
+ *							gpointer user_data)
+ *
+ * Description
+ *   
+ *   
+ *
+ * Return value
+ *   void
+ */
+
+void on_colorbutton7_color_set(GtkColorButton * colorbutton,
+                                       			 gpointer user_data)
+{
+	gchar *buf2 = NULL;
+ 	GdkColor color;
+	
+	gtk_color_button_get_color(colorbutton, &color);
+	buf2 = gdkcolor_to_hex(color,1); 
+	xml_set_value("GnomeSword", "HTMLcolors", "highlight_bg", buf2);
+	settings.highlight_bg = xml_get_value("HTMLcolors", "highlight_bg");
+	if (buf2)
+		g_free(buf2);
+	apply_color_settings();
+}
+
 /******************************************************************************
  * Name
  *   on_checkbutton1_toggled
@@ -628,11 +702,9 @@ void on_checkbutton4_toggled(GtkToggleButton *togglebutton, gpointer user_data)
 void on_checkbutton5_toggled(GtkToggleButton * togglebutton, gpointer user_data)
 {
 	extern gboolean style_display;
-	if (togglebutton->active)
-		xml_set_value("GnomeSword", "misc", "versestyle", "1");
-	else
-		xml_set_value("GnomeSword", "misc", "versestyle", "0");
-	settings.versestyle = atoi(xml_get_value("misc", "versestyle"));
+	xml_set_value("GnomeSword", "misc", "versestyle",
+		      (togglebutton->active ? "1" : "0"));
+	settings.versestyle = togglebutton->active;
 	
 	style_display = TRUE;	
 	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM
@@ -662,7 +734,6 @@ void on_checkbutton10_toggled(GtkToggleButton * togglebutton, gpointer user_data
 	xml_set_value("GnomeSword", "misc", "pinnedtabs",
 		      (togglebutton->active ? "1" : "0"));
 	settings.pinnedtabs = atoi(xml_get_value("misc", "pinnedtabs"));
-	
 	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM
 			       (widgets.pinnedtabs_item),
 			       settings.pinnedtabs);
@@ -691,7 +762,6 @@ void on_checkbutton11_toggled(GtkToggleButton * togglebutton, gpointer user_data
 	xml_set_value("GnomeSword", "misc", "readaloud",
 		      (togglebutton->active ? "1" : "0"));
 	settings.readaloud = atoi(xml_get_value("misc", "readaloud"));
-	
 	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM
 			       (widgets.readaloud_item),
 			       settings.readaloud);
@@ -746,12 +816,9 @@ void on_checkbutton12_toggled(GtkToggleButton * togglebutton, gpointer user_data
 
 void on_checkbutton6_toggled(GtkToggleButton * togglebutton, gpointer user_data)
 {
-	if (togglebutton->active)
-		xml_set_value("GnomeSword", "lexicons", "usedefaultdict", "1");
-	else
-		xml_set_value("GnomeSword", "lexicons", "usedefaultdict", "0");
-	settings.useDefaultDict =
-			atoi(xml_get_value("lexicons", "usedefaultdict"));
+	xml_set_value("GnomeSword", "lexicons", "usedefaultdict",
+		      (togglebutton->active ? "1" : "0"));
+	settings.useDefaultDict = togglebutton->active;
 }
 
 
@@ -774,11 +841,9 @@ void on_checkbutton6_toggled(GtkToggleButton * togglebutton, gpointer user_data)
 
 void on_checkbutton7_toggled(GtkToggleButton * togglebutton, gpointer user_data)
 {
-	if(togglebutton->active)
-		xml_set_value("GnomeSword", "misc", "dailydevotional", "1");
-	else
-		xml_set_value("GnomeSword", "misc", "dailydevotional", "0");
-	settings.showdevotional = atoi(xml_get_value("misc","dailydevotional"));
+	xml_set_value("GnomeSword", "misc", "dailydevotional",
+		      (togglebutton->active ? "1" : "0"));
+	settings.showdevotional = togglebutton->active;
 }
 
 
@@ -801,15 +866,12 @@ void on_checkbutton7_toggled(GtkToggleButton * togglebutton, gpointer user_data)
 
 void on_checkbutton8_toggled(GtkToggleButton * togglebutton, gpointer user_data)
 {
-	if (togglebutton->active)
-		xml_set_value("GnomeSword", "misc", "splash", "1");
-	else
-		xml_set_value("GnomeSword", "misc", "splash", "0");
-	settings.showsplash = atoi(xml_get_value("misc", "splash"));
+	xml_set_value("GnomeSword", "misc", "splash",
+		      (togglebutton->active ? "1" : "0"));
+	settings.showsplash = togglebutton->active;
 }
 
 
-
 /******************************************************************************
  * Name
  *   on_checkbutton_scroll_toggled
@@ -829,14 +891,9 @@ void on_checkbutton8_toggled(GtkToggleButton * togglebutton, gpointer user_data)
 
 void on_checkbutton_scroll_toggled(GtkToggleButton * togglebutton, gpointer user_data)
 {
-	gchar *buf;
-	
-	if (togglebutton->active)
-		xml_set_value("GnomeSword", "misc", "chapter-scroll", "1");
-	else
-		xml_set_value("GnomeSword", "misc", "chapter-scroll", "0");
-	buf = xml_get_value("misc", "chapter-scroll");
-	settings.chapter_scroll = atoi(buf);
+	xml_set_value("GnomeSword", "misc", "chapter-scroll",
+		      (togglebutton->active ? "1" : "0"));
+	settings.chapter_scroll = togglebutton->active;
 }
 
 /******************************************************************************
@@ -858,16 +915,66 @@ void on_checkbutton_scroll_toggled(GtkToggleButton * togglebutton, gpointer user
 
 void on_checkbutton_imageresize_toggled(GtkToggleButton * togglebutton, gpointer user_data)
 {
-	gchar *buf;
-	
-	if (togglebutton->active)
-		xml_set_value("GnomeSword", "misc", "imageresize", "1");
-	else
-		xml_set_value("GnomeSword", "misc", "imageresize", "0");
-	buf = xml_get_value("misc", "imageresize");
-	settings.imageresize =  atoi(buf);
+	xml_set_value("GnomeSword", "misc", "imageresize",
+		      (togglebutton->active ? "1" : "0"));
+	settings.imageresize =  togglebutton->active;
 }
 
+/******************************************************************************
+ * Name
+ *   on_checkbutton_versehighlight_toggled
+ *
+ * Synopsis
+ *   #include "preferences_dialog.h"
+ *
+ *   void on_checkbutton_versehighlight_toggled(GtkToggleButton * togglebutton, gpointer user_data)
+ *
+ * Description
+ *   
+ *   
+ *
+ * Return value
+ *   void
+ */
+
+void on_checkbutton_versehighlight_toggled(GtkToggleButton * togglebutton, gpointer user_data)
+{
+	xml_set_value("GnomeSword", "misc", "versehighlight",
+		      (togglebutton->active ? "1" : "0"));
+	settings.versehighlight = togglebutton->active;
+	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM
+			       (widgets.versehighlight_item),
+			       settings.versehighlight);
+	main_display_bible(settings.MainWindowModule, settings.currentverse);
+}
+
+/******************************************************************************
+ * Name
+ *   on_checkbutton_doublespace_toggled
+ *
+ * Synopsis
+ *   #include "preferences_dialog.h"
+ *
+ *   void on_checkbutton_doublespace_toggled(GtkToggleButton * togglebutton, gpointer user_data)
+ *
+ * Description
+ *   
+ *   
+ * Return value
+ *   void
+ */
+
+void on_checkbutton_doublespace_toggled(GtkToggleButton * togglebutton, gpointer user_data)
+{
+	xml_set_value("GnomeSword", "misc", "doublespace",
+		      (togglebutton->active ? "1" : "0"));
+	settings.doublespace = togglebutton->active;
+	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM
+			       (widgets.doublespace_item),
+			       settings.doublespace);
+}
+
+
 /******************************************************************************
  * Name
  *   on_folder_changed
@@ -1567,6 +1674,7 @@ static void setup_color_pickers(void)
                                         &color);
 	}
 
+/*
 	if (string_is_color(settings.bible_verse_num_color)) {
 		gdk_color_parse(settings.bible_verse_num_color, &color);
 		gtk_color_button_set_color(
@@ -1578,6 +1686,7 @@ static void setup_color_pickers(void)
 			GTK_COLOR_BUTTON(color_picker.verse_numbers),
                                         &color);
 	}
+*/
 
 	if (string_is_color(settings.link_color)) {
 		gdk_color_parse(settings.link_color, &color);
@@ -1590,6 +1699,24 @@ static void setup_color_pickers(void)
 			GTK_COLOR_BUTTON(color_picker.href_links),
                                         &color);
 	}
+
+	// contrasty highlighting -- foreground.
+	if (string_is_color(settings.highlight_fg))
+		gdk_color_parse(settings.highlight_fg, &color);
+	else
+		gdk_color_parse("#FFFF00", &color);
+	gtk_color_button_set_color(
+		GTK_COLOR_BUTTON(color_picker.highlight_fg),
+				&color);
+
+	// contrasty highlighting -- background.
+	if (string_is_color(settings.highlight_bg))
+		gdk_color_parse(settings.highlight_bg, &color);
+	else
+		gdk_color_parse("#060680", &color);
+	gtk_color_button_set_color(
+		GTK_COLOR_BUTTON(color_picker.highlight_bg),
+				&color);
 }
 
 
@@ -1628,6 +1755,14 @@ static void setup_check_buttons(void)
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON
 				     (check_button.use_imageresize),
 				     settings.imageresize);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON
+				     (check_button.versehighlight),
+				     settings.versehighlight);
+#ifdef DOUBLESPACE
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON
+				     (check_button.doublespace),
+				     settings.doublespace);
+#endif /* DOUBLESPACE */
 
 	g_signal_connect(check_button.enable_tabbed_browsing, "toggled",
 			 G_CALLBACK(on_checkbutton1_toggled), NULL);
@@ -1651,7 +1786,12 @@ static void setup_check_buttons(void)
 			 G_CALLBACK(on_checkbutton_scroll_toggled), NULL);
 	g_signal_connect(check_button.use_imageresize, "toggled",
 			 G_CALLBACK(on_checkbutton_imageresize_toggled), NULL);
-	
+	g_signal_connect(check_button.versehighlight, "toggled",
+			 G_CALLBACK(on_checkbutton_versehighlight_toggled), NULL);
+#ifdef DOUBLESPACE
+	g_signal_connect(check_button.doublespace, "toggled",
+			 G_CALLBACK(on_checkbutton_doublespace_toggled), NULL);
+#endif /* DOUBLESPACE */
 }
 
 
@@ -1758,8 +1898,10 @@ void setup_module_comboboxs(void)
 		fill_combobox(glist,GTK_COMBO_BOX(combo.parallel_5_module), settings.parallel5Module);
 	/* Miscellaneous Modules page */
 	glist = get_list(DEVOTION_LIST);
-	if(glist) 
+	if(glist)  {
 		fill_combobox(glist,GTK_COMBO_BOX(combo.devotion_module), settings.devotionalmod);
+		
+	}
 	glist = get_list(DICT_LIST);
 	if(glist) 
 		fill_combobox(glist,GTK_COMBO_BOX(combo.hebrew_lex__module), settings.lex_hebrew);
@@ -1855,12 +1997,21 @@ static void create_preferences_dialog(void)
 	color_picker.text_current_verse = glade_xml_get_widget (gxml, "colorbutton3");
 	g_signal_connect(color_picker.text_current_verse, "color_set",
 			 G_CALLBACK(on_colorbutton3_color_set), NULL);
+/*
 	color_picker.verse_numbers = glade_xml_get_widget (gxml, "colorbutton4");
 	g_signal_connect(color_picker.verse_numbers, "color_set",
 			 G_CALLBACK(on_colorbutton4_color_set), NULL);
+*/
 	color_picker.href_links = glade_xml_get_widget (gxml, "colorbutton5");
 	g_signal_connect(color_picker.href_links, "color_set",
 			 G_CALLBACK(on_colorbutton5_color_set), NULL);
+	color_picker.highlight_fg = glade_xml_get_widget (gxml, "colorbutton6");
+	g_signal_connect(color_picker.highlight_fg, "color_set",
+			 G_CALLBACK(on_colorbutton6_color_set), NULL);
+	color_picker.highlight_bg = glade_xml_get_widget (gxml, "colorbutton7");
+	g_signal_connect(color_picker.highlight_bg, "color_set",
+			 G_CALLBACK(on_colorbutton7_color_set), NULL);
+
 	setup_color_pickers();
 	/* check buttons */
 	check_button.enable_tabbed_browsing = glade_xml_get_widget(gxml, "checkbutton1");
@@ -1877,6 +2028,8 @@ static void create_preferences_dialog(void)
 	check_button.show_splash_screen = glade_xml_get_widget(gxml, "checkbutton8");
 	check_button.use_chapter_scroll = glade_xml_get_widget(gxml, "checkbutton_scroll");
 	check_button.use_imageresize = glade_xml_get_widget(gxml, "checkbutton_imageresize");
+	check_button.versehighlight = glade_xml_get_widget(gxml, "checkbutton_versehighlight");
+	check_button.doublespace = glade_xml_get_widget(gxml, "checkbutton_doublespace");
 	setup_check_buttons();
 	/* verse number size */
 	index = get_verse_number_size_index();
