@@ -738,8 +738,16 @@ gboolean gui_verselist_button_release_event(GtkWidget * widget,
 			break;
 		}
 	}
-	text =
-	    main_get_search_results_text(settings.sb_search_mod, key);
+	// UTF-8 workaround (domcox)
+	// main_get_search_results_text (renderText) doesn't render 
+	// non-ascii chars saved in numeric character reference format 
+	// in personal notes.
+	// Notes are now saved in utf8 encoding (GnomeSword > 2.2.2.1)
+	if( main_get_mod_type(settings.sb_search_mod) == PERCOM_TYPE)
+		text = main_get_raw_text(settings.sb_search_mod, key);
+	else
+		text = main_get_search_results_text(settings.sb_search_mod, key);
+
 	if (text) {
 		settings.displaySearchResults = TRUE;
 		main_entry_display(sidebar.html_viewer_widget, //sidebar.html_widget,
@@ -1101,7 +1109,9 @@ static gboolean tree_key_press_cb(GtkWidget * widget,
 	    g_strdup_printf("sword://%s/%s", settings.sb_search_mod,
 			    key);
 
+#ifdef DEBUG
 	g_warning("%d", event->keyval);
+#endif
 	if (event) {
 		switch (event->keyval) {
 		case 65293:
@@ -1479,6 +1489,58 @@ GtkWidget *gui_create_sidebar(GtkWidget * paned)
 	gtk_paned_pack1(GTK_PANED(paned), vbox1, FALSE, TRUE);
 	widgets.shortcutbar = vbox1;
 
+	table2 = gtk_table_new(2, 2, TRUE);
+	gtk_widget_show(table2);
+	gtk_box_pack_start(GTK_BOX(vbox1), table2, FALSE, TRUE, 0);
+	gtk_container_set_border_width(GTK_CONTAINER(table2), 2);
+	gtk_table_set_row_spacings(GTK_TABLE(table2), 6);
+	gtk_table_set_col_spacings(GTK_TABLE(table2), 6);
+
+	button_bookmarks =
+	    gtk_toggle_button_new_with_mnemonic(_("Bookmarks"));
+	gtk_widget_show(button_bookmarks);
+	gtk_table_attach(GTK_TABLE(table2), button_bookmarks, 1, 2, 0,
+			 1, (GtkAttachOptions) (GTK_FILL),
+			 (GtkAttachOptions) (0), 0, 0);
+	gtk_button_set_relief(GTK_BUTTON(button_bookmarks),
+			      GTK_RELIEF_HALF);
+	gtk_button_set_focus_on_click(GTK_BUTTON(button_bookmarks),
+				      FALSE);
+
+	button_search =
+	    gtk_toggle_button_new_with_mnemonic(_("Search"));
+	gtk_widget_show(button_search);
+	gtk_table_attach(GTK_TABLE(table2), button_search, 0, 1, 1, 2,
+			 (GtkAttachOptions) (GTK_FILL),
+			 (GtkAttachOptions) (0), 0, 0);
+	gtk_button_set_relief(GTK_BUTTON(button_search),
+			      GTK_RELIEF_HALF);
+	gtk_button_set_focus_on_click(GTK_BUTTON(button_search), FALSE);
+
+	button_v_lists =
+	    gtk_toggle_button_new_with_mnemonic(_("Verse List"));
+	gtk_widget_show(button_v_lists);
+	gtk_table_attach(GTK_TABLE(table2), button_v_lists, 1, 2, 1, 2,
+			 (GtkAttachOptions) (GTK_FILL),
+			 (GtkAttachOptions) (0), 0, 0);
+	gtk_button_set_relief(GTK_BUTTON(button_v_lists),
+			      GTK_RELIEF_HALF);
+	gtk_button_set_focus_on_click(GTK_BUTTON(button_v_lists),
+				      FALSE);
+
+	button_modules =
+	    gtk_toggle_button_new_with_mnemonic(_("Modules"));
+	gtk_widget_show(button_modules);
+	gtk_table_attach(GTK_TABLE(table2), button_modules, 0, 1, 0, 1,
+			 (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+			 (GtkAttachOptions) (0), 0, 0);
+	gtk_button_set_relief(GTK_BUTTON(button_modules),
+			      GTK_RELIEF_HALF);
+	gtk_button_set_focus_on_click(GTK_BUTTON(button_modules),
+				      FALSE);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button_modules),
+				     TRUE);
+
 	widgets.notebook_sidebar = gtk_notebook_new();
 	gtk_widget_show(widgets.notebook_sidebar);
 
@@ -1545,58 +1607,6 @@ GtkWidget *gui_create_sidebar(GtkWidget * paned)
 	sidebar.menu_modules = create_menu_modules();
 
 
-	table2 = gtk_table_new(2, 2, TRUE);
-	gtk_widget_show(table2);
-	gtk_box_pack_start(GTK_BOX(vbox1), table2, FALSE, TRUE, 0);
-	gtk_container_set_border_width(GTK_CONTAINER(table2), 2);
-	gtk_table_set_row_spacings(GTK_TABLE(table2), 6);
-	gtk_table_set_col_spacings(GTK_TABLE(table2), 6);
-
-	button_bookmarks =
-	    gtk_toggle_button_new_with_mnemonic(_("Bookmarks"));
-	gtk_widget_show(button_bookmarks);
-	gtk_table_attach(GTK_TABLE(table2), button_bookmarks, 1, 2, 0,
-			 1, (GtkAttachOptions) (GTK_FILL),
-			 (GtkAttachOptions) (0), 0, 0);
-	gtk_button_set_relief(GTK_BUTTON(button_bookmarks),
-			      GTK_RELIEF_HALF);
-	gtk_button_set_focus_on_click(GTK_BUTTON(button_bookmarks),
-				      FALSE);
-
-	button_search =
-	    gtk_toggle_button_new_with_mnemonic(_("Search"));
-	gtk_widget_show(button_search);
-	gtk_table_attach(GTK_TABLE(table2), button_search, 0, 1, 1, 2,
-			 (GtkAttachOptions) (GTK_FILL),
-			 (GtkAttachOptions) (0), 0, 0);
-	gtk_button_set_relief(GTK_BUTTON(button_search),
-			      GTK_RELIEF_HALF);
-	gtk_button_set_focus_on_click(GTK_BUTTON(button_search), FALSE);
-
-	button_v_lists =
-	    gtk_toggle_button_new_with_mnemonic(_("Verse List"));
-	gtk_widget_show(button_v_lists);
-	gtk_table_attach(GTK_TABLE(table2), button_v_lists, 1, 2, 1, 2,
-			 (GtkAttachOptions) (GTK_FILL),
-			 (GtkAttachOptions) (0), 0, 0);
-	gtk_button_set_relief(GTK_BUTTON(button_v_lists),
-			      GTK_RELIEF_HALF);
-	gtk_button_set_focus_on_click(GTK_BUTTON(button_v_lists),
-				      FALSE);
-
-	button_modules =
-	    gtk_toggle_button_new_with_mnemonic(_("Modules"));
-	gtk_widget_show(button_modules);
-	gtk_table_attach(GTK_TABLE(table2), button_modules, 0, 1, 0, 1,
-			 (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-			 (GtkAttachOptions) (0), 0, 0);
-	gtk_button_set_relief(GTK_BUTTON(button_modules),
-			      GTK_RELIEF_HALF);
-	gtk_button_set_focus_on_click(GTK_BUTTON(button_modules),
-				      FALSE);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button_modules),
-				     TRUE);
-
 	g_signal_connect((gpointer) button_bookmarks, "toggled",
 			 G_CALLBACK(on_bookmarks_activate), NULL);
 	g_signal_connect((gpointer) button_search, "toggled",
