@@ -280,7 +280,7 @@ void gui_load_tabs(const gchar *filename)
 	gboolean error = FALSE;
 
 	GList *tmp = NULL;
-	PASSAGE_TAB_INFO *pt = NULL;
+	PASSAGE_TAB_INFO *pt = NULL, *pt_first = NULL;
 
 	if (filename == NULL)
 	{
@@ -328,6 +328,8 @@ void gui_load_tabs(const gchar *filename)
 						if (!xmlStrcmp(tmp_node->name, (const xmlChar*)"tab"))
 						{
 							pt = g_new0(PASSAGE_TAB_INFO, 1);
+							if (pt_first == NULL)
+								pt_first = pt;
 							
 							val = (gchar*)xmlGetProp(tmp_node, (const xmlChar *)"text_mod");
 							pt->text_mod = g_strdup(val);
@@ -384,6 +386,9 @@ void gui_load_tabs(const gchar *filename)
 		}
 		else
 		{
+			// first passage is current/displayed.
+			pt = pt_first;
+
 			// This is a hack to keep gs from loading the settings from the last session
 			// into the last tab loaded here.
 			settings.MainWindowModule = g_strdup(pt->text_mod);
@@ -592,11 +597,14 @@ void gui_set_tab_label(const gchar * key)
 	if (settings.pinnedtabs) {
 		GList *tmp = NULL;
 		for (tmp = g_list_first(passage_list); tmp != NULL; tmp = g_list_next(tmp))
-			gui_set_named_tab_label(key, (PASSAGE_TAB_INFO*)tmp->data);
+			gui_set_named_tab_label
+			    (key,
+			     (PASSAGE_TAB_INFO*)tmp->data,
+			     ((PASSAGE_TAB_INFO*)tmp->data == cur_passage_tab));
 	}
 	else
 	{
-		gui_set_named_tab_label(key, cur_passage_tab);
+		gui_set_named_tab_label(key, cur_passage_tab, TRUE);
 	}
 }
 
@@ -616,7 +624,7 @@ void gui_set_tab_label(const gchar * key)
  *   void
  */
  
-void gui_set_named_tab_label(const gchar * key, PASSAGE_TAB_INFO *pt)
+void gui_set_named_tab_label(const gchar * key, PASSAGE_TAB_INFO *pt, gboolean update)
 {
 	GString *str = g_string_new(NULL);
 	
@@ -635,7 +643,8 @@ void gui_set_named_tab_label(const gchar * key, PASSAGE_TAB_INFO *pt)
 					GTK_NOTEBOOK(widgets.notebook_main),
                                         pt->page_widget,
                                             str->str );
-	main_add_tab_history_item((PASSAGE_TAB_INFO*)pt);
+	if (update)
+		main_add_tab_history_item((PASSAGE_TAB_INFO*)pt);
 	g_string_free(str,TRUE);
 }
 
@@ -663,6 +672,9 @@ void gui_update_tab_struct(const gchar * text_mod,
 			   const gchar * book_offset,
 			   gboolean comm_showing)
 {	
+	if(!settings.browsing)
+	        return;
+	
 	if(page_change) 
 		return;
 	
