@@ -206,7 +206,7 @@ on_button_forward_clicked(GtkButton * button, gpointer user_data)
 }
 
 
-static void handle_spinbutton_click(gint button, gint direction)
+void gui_navbar_handle_spinbutton_click(gint button, gint direction)
 {
 	gchar *url = NULL;
 	gchar *book = NULL;
@@ -303,43 +303,45 @@ static void handle_spinbutton_click(gint button, gint direction)
 static void
 on_verse_button_up_clicked(GtkButton * button, gpointer user_data)
 {
-	handle_spinbutton_click(2, 0);
+	gui_navbar_handle_spinbutton_click(2, 0);
 }
 
 
 static void
 on_verse_button_down_clicked(GtkButton * button, gpointer user_data)
 {
-	handle_spinbutton_click(2, 1);
+	gui_navbar_handle_spinbutton_click(2, 1);
 }
 
 
 static void
 on_chapter_button_up_clicked(GtkButton * button, gpointer user_data)
 {
-	handle_spinbutton_click(1, 0);
+	gui_navbar_handle_spinbutton_click(1, 0);
 }
 
 
 static void
 on_chapter_button_down_clicked(GtkButton * button, gpointer user_data)
 {
-	handle_spinbutton_click(1, 1);
+	gui_navbar_handle_spinbutton_click(1, 1);
 }
 
 
 static void
 on_book_button_up_clicked(GtkButton * button, gpointer user_data)
 {
+#ifdef DEBUG
 	g_message("on_book_button_up_clicked");
-	handle_spinbutton_click(0, 0);
+#endif
+	gui_navbar_handle_spinbutton_click(0, 0);
 }
 
 
 static void
 on_book_button_down_clicked(GtkButton * button, gpointer user_data)
 {
-	handle_spinbutton_click(0, 1);
+	gui_navbar_handle_spinbutton_click(0, 1);
 }
 
 
@@ -348,7 +350,7 @@ on_comboboxentry4_changed(GtkComboBox * combobox, gpointer data)
 {
 	gchar *url = NULL;
 	gchar *book = NULL;
-	gchar *buf = NULL;
+	//gchar *buf = NULL;
 	GtkTreeIter iter;
 	gsize bytes_read;
 	gsize bytes_written;
@@ -358,11 +360,11 @@ on_comboboxentry4_changed(GtkComboBox * combobox, gpointer data)
 
 	if (!do_display)
 		return;
-#ifdef DEBUG
-	g_message("on_comboboxentry4_changed");
-#endif
 	gtk_combo_box_get_active_iter(combobox, &iter);
 	gtk_tree_model_get(GTK_TREE_MODEL(model), &iter, 0, &book, -1);
+#ifdef DEBUG
+	g_message("on_comboboxentry4_changed: %s",book);
+#endif
 	//      g_error_free (error);
 /*	key = g_convert(book,
 			     -1,
@@ -377,13 +379,13 @@ on_comboboxentry4_changed(GtkComboBox * combobox, gpointer data)
 		return;
 	}*/
 	url = g_strdup_printf("sword:///%s 1:1", book);
-	buf = g_strdup_printf("%s 1:1", book);
+	//buf = g_strdup_printf("%s 1:1", book);
 
 	main_url_handler(url, TRUE);
-	main_navbar_set(navbar_main, buf);
+	//main_navbar_set(navbar_main, buf);
 	g_free(url);
 	g_free(book);
-	g_free(buf);
+	//g_free(buf);
 	//g_free(key);
 }
 
@@ -394,7 +396,7 @@ on_comboboxentry5_changed(GtkComboBox * combobox, gpointer data)
 	gchar *url = NULL;
 	gchar *book = NULL;
 	gchar *chapter = NULL;
-	gchar *buf = NULL;
+	//gchar *buf = NULL;
 	GtkTreeIter iter;
 
 	GtkTreeModel *model = gtk_combo_box_get_model(combobox);
@@ -419,14 +421,14 @@ on_comboboxentry5_changed(GtkComboBox * combobox, gpointer data)
 			   -1);
 
 	url = g_strdup_printf("sword:///%s %s:1", book, chapter);
-	buf = g_strdup_printf("%s %s:1", book, chapter);
+	//buf = g_strdup_printf("%s %s:1", book, chapter);
 	main_url_handler(url, TRUE);
-	main_navbar_set(navbar_main, buf);
+	//main_navbar_set(navbar_main, buf);
 
 	g_free(url);
 	g_free(book);
 	g_free(chapter);
-	g_free(buf);
+	//g_free(buf);
 }
 
 
@@ -437,7 +439,7 @@ on_comboboxentry6_changed(GtkComboBox * combobox, gpointer data)
 	gchar *book = NULL;
 	gchar *chapter = NULL;
 	gchar *verse = NULL;
-	gchar *buf = NULL;
+	//gchar *buf = NULL;
 	gsize bytes_read;
 	gsize bytes_written;
 	GError *error = NULL;
@@ -475,15 +477,15 @@ on_comboboxentry6_changed(GtkComboBox * combobox, gpointer data)
 
 	url =
 	    g_strdup_printf("sword:///%s %s:%s", book, chapter, verse);
-	buf = g_strdup_printf("%s %s:%s", book, chapter, verse);
+	//buf = g_strdup_printf("%s %s:%s", book, chapter, verse);
 	main_url_handler(url, TRUE);
-	main_navbar_set(navbar_main, buf);
+	//main_navbar_set(navbar_main, buf);
 
 	g_free(url);
 	g_free(book);
 	g_free(chapter);
 	g_free(verse);
-	g_free(buf);
+	//g_free(buf);
 }
 
 /******************************************************************************
