@@ -59,6 +59,11 @@ int main(int argc, char *argv[])
 
 	gui_init(argc, argv);
 	
+	if (argc > 2) {
+		gui_generic_warning("GnomeSword does not understand more than one argument.");
+		exit(1);
+	}
+
 	if (argc > 1) {
 		/*
 		 * these args are for broken configs or bookmarks -
@@ -77,7 +82,11 @@ int main(int argc, char *argv[])
 		/*
 		 * this arg is a sword uri
 		 */
-		if ((!strncmp(argv[1], "sword:/",7)) || (strstr(argv[1],"studypad"))) {
+		if ((!strncmp(argv[1], "sword:/", 7)) ||
+		    (!strncmp(argv[1], "bible:/", 7)) ||
+		    (strstr(argv[1], "studypad"))) {
+			if (!strncmp(argv[1], "bible:/", 7))
+				memcpy(argv[1], "sword", 5); /* equivalent */
 			have_sword_url = TRUE;
 		}
 	}
@@ -106,8 +115,17 @@ int main(int argc, char *argv[])
 	
 	gui_splash_done();
 	
-	if(have_sword_url)
+	if (have_sword_url) {
+		if (!strncmp(argv[1], "sword:/", 7)) {
+			char *key = strchr(argv[1]+8, '/');
+			if (key && *(key+1) != '\0')
+				key++;
+			else
+				key = "Gen 1:1";
+			gui_open_passage_in_new_tab(key);
+		}
 		main_url_handler(argv[1], TRUE);
+	}
 
 	/*gtk_notebook_set_current_page(GTK_NOTEBOOK
 					(widgets.notebook_comm_book), 0);*/
