@@ -41,12 +41,6 @@ extern "C" {
 
 #include <string.h>
 
-
-#ifndef USE_GTKHTML38
-#include "editor/editor.h"
-#include "editor/editor-control.h"
-#endif
-
 #include "gui/bibletext_dialog.h"
 #include "gui/commentary_dialog.h"
 #include "gui/dictlex_dialog.h"
@@ -56,11 +50,11 @@ extern "C" {
 #include "gui/sidebar.h"
 #include "gui/html.h"
 #include "gui/main_window.h"
-#include "gui/note_editor.h"
 #include "gui/gnomesword.h"
 #include "gui/utilities.h"
 #include "gui/widgets.h"
 
+#include "main/navbar_book_dialog.h"
 #include "main/module_dialogs.h"
 #include "main/sword.h"
 #include "main/sidebar.h"
@@ -707,12 +701,12 @@ void main_dialogs_tree_selection_changed(GtkTreeModel * model,
 
 /******************************************************************************
  * Name
- *   main_dialogs_dictionary_entery_changed
+ *   main_dialogs_dictionary_entry_changed
  *
  * Synopsis
  *   #include ".h"
  *
- *   void main_dialogs_dictionary_entery_changed(DIALOG_DATA * d)	
+ *   void main_dialogs_dictionary_entry_changed(DIALOG_DATA * d)	
  *
  * Description
  *   
@@ -721,7 +715,7 @@ void main_dialogs_tree_selection_changed(GtkTreeModel * model,
  *   void
  */
 
-void main_dialogs_dictionary_entery_changed(DIALOG_DATA * d)
+void main_dialogs_dictionary_entry_changed(DIALOG_DATA * d)
 {
 	gint count = 10, i;
 	gchar *new_key, *text = NULL;
@@ -1712,14 +1706,14 @@ DIALOG_DATA *main_dialogs_open(const gchar * mod_name ,  const gchar * key)
 			t->mod_type = TEXT_TYPE;
 			gui_create_bibletext_dialog(t);
 #ifdef USE_GTKMOZEMBED
-			be->chapDisplay = new DialogChapDisp(t->html, be, t->ops);
+			be->chapDisplay = new DialogChapDisp(t->html, t, be, t->ops);
 #else
 			if(t->is_rtol)
 				be->dialogRTOLDisplay 
-				   = new DialogTextviewChapDisp(t->text, be, t->ops);
+				   = new DialogTextviewChapDisp(t->text,  t, be, t->ops);
 			else	
 				be->chapDisplay 
-				      = new DialogChapDisp(t->html, be, t->ops); 
+				      = new DialogChapDisp(t->html,  t, be, t->ops); 
 #endif
 			be->init_SWORD(1);
 			if(key)
@@ -1735,7 +1729,7 @@ DIALOG_DATA *main_dialogs_open(const gchar * mod_name ,  const gchar * key)
 		case COMMENTARY_TYPE:
 			t->mod_type = COMMENTARY_TYPE;
 			gui_create_commentary_dialog(t, FALSE);
-			be->entryDisplay = new DialogEntryDisp(t->html, be, t->ops); 
+			be->entryDisplay = new DialogEntryDisp(t->html,  t, be, t->ops); 
 			be->init_SWORD(1);
 			if(key)
 				t->key = g_strdup(key);
@@ -1755,7 +1749,7 @@ DIALOG_DATA *main_dialogs_open(const gchar * mod_name ,  const gchar * key)
 			strcpy(ec->filename, t->mod_name);
 			t->is_percomm = TRUE;
 			be->entryDisplay 
-				    = new DialogEntryDisp(ec->htmlwidget, be, t->ops); 
+				    = new DialogEntryDisp(ec->htmlwidget,  t, be, t->ops); 
 			be->init_SWORD(1);
 			ec->be = (BackEnd*)be;
 			if(key)
@@ -1773,7 +1767,7 @@ DIALOG_DATA *main_dialogs_open(const gchar * mod_name ,  const gchar * key)
 		case DICTIONARY_TYPE:
 			t->mod_type = DICTIONARY_TYPE;
 			gui_create_dictlex_dialog(t);
-			be->entryDisplay = new DialogEntryDisp(t->html, be, t->ops); 
+			be->entryDisplay = new DialogEntryDisp(t->html,  t, be, t->ops); 
 			be->init_SWORD(1);
 			if(key)
 				t->key = g_strdup(key);
@@ -1783,7 +1777,7 @@ DIALOG_DATA *main_dialogs_open(const gchar * mod_name ,  const gchar * key)
 		case BOOK_TYPE:
 			t->mod_type = BOOK_TYPE;
 			gui_create_gbs_dialog(t);
-			be->entryDisplay = new DialogEntryDisp(t->html, be, t->ops); 
+			be->entryDisplay = new DialogEntryDisp(t->html,  t, be, t->ops); 
 			be->init_SWORD(1);
 			t->key = NULL; 
 			if(key)
@@ -1802,6 +1796,7 @@ DIALOG_DATA *main_dialogs_open(const gchar * mod_name ,  const gchar * key)
 		main_dialogs_add_book_to_tree(t->tree, t->mod_name, 
 			     TRUE, t);
 		be->set_treekey(t->offset);
+		main_setup_navbar_book_dialog(t);
 #ifdef DEBUG
 		g_message("offset = %d",t->offset);
 #endif
@@ -1815,14 +1810,10 @@ DIALOG_DATA *main_dialogs_open(const gchar * mod_name ,  const gchar * key)
 		t->is_locked = 0;
 		t->cipher_old = NULL;
 	}	
-	
-	be->display_mod->Display();
-	bible_apply_change = TRUE;
-	
-#ifndef USE_GTKHTML38
-	if(type == PERCOM_TYPE)
-		gtk_html_set_editable(ec->html, TRUE);
-#endif
+	if(type != BOOK_TYPE) {
+		be->display_mod->Display();
+		bible_apply_change = TRUE;
+	}
 	if(type == DICTIONARY_TYPE)
 		gtk_entry_set_text(GTK_ENTRY(t->entry),t->key);	
 	return t;
