@@ -30,6 +30,7 @@ typedef struct _dialog_data DIALOG_DATA;
 
 #include "main/global_ops.hh"
 #include "main/navbar.h"
+#include "main/navbar_book.h"
 
 struct _dialog_data {
 	/* dialog widgets */
@@ -77,6 +78,7 @@ struct _dialog_data {
 	
         GObject *mod_selection;
 	NAVBAR navbar;
+	NAVBAR_BOOK navbar_book;
 	GLOBAL_OPS *ops;
 };
 
@@ -94,7 +96,7 @@ void main_dialogs_add_book_to_tree(GtkWidget * tree, gchar * mod_name,
 void main_dialogs_tree_selection_changed(GtkTreeModel * model, 
 	   GtkTreeSelection * selection, gboolean is_dialog, DIALOG_DATA * g);
 
-void main_dialogs_dictionary_entery_changed(DIALOG_DATA * d);
+void main_dialogs_dictionary_entry_changed(DIALOG_DATA * d);
 void main_dialog_save_note(gpointer data);
 void main_dialog_delete_note(gpointer data);
 
