@@ -157,8 +157,8 @@ void main_navbar_fill_book_combo(NAVBAR navbar)
 	gtk_list_store_clear(GTK_LIST_STORE(book_model));
 	if (backend->module_has_testament(navbar.module_name, 1)) {
 		while(i < key.BMAX[0]) { 			
-			key_abrev = key.books[0][i].name;
-			book = g_convert((const char *)key_abrev.getBookAbbrev(),
+			//key_abrev = key.books[0][i].name;
+			book = g_convert((const char *) key.books[0][i].name,   //key_abrev.getBookAbbrev(),
 				     -1,
 				     UTF_8,
 				     OLD_CODESET,
@@ -184,8 +184,8 @@ void main_navbar_fill_book_combo(NAVBAR navbar)
 	i = 0;
 	if (backend->module_has_testament(navbar.module_name, 2)) {
 		while(i < key.BMAX[1]) {			
-			key_abrev = key.books[1][i].name;
-			book = g_convert((const char *)key_abrev.getBookAbbrev(),
+			//key_abrev = key.books[1][i].name;
+			book = g_convert((const char *) key.books[1][i].name,   //key_abrev.getBookAbbrev(),
 				     -1,
 				     UTF_8,
 				     OLD_CODESET,
