@@ -26,12 +26,14 @@
 extern "C" {
 #endif
 
-#include <glib-2.0/glib.h>
+//#include <glib-2.0/glib.h>
 	
 void main_sidebar_search_percent_update(char percent, void *userData);
 void main_do_sidebar_search(gpointer user_data);
+void main_sidebar_perscomm_dump(void);
 void main_init_sidebar_search_backend(void);
 void main_delete_sidebar_search_backend(void);
+void main_search_sidebar_fill_bounds_combos(void);
 
 #ifdef __cplusplus
 }
