@@ -24,7 +24,7 @@
 #include <config.h>
 #endif
 
-#include <glib-2.0/glib.h>
+#include <gnome.h>
 
 #include <fcntl.h>
 #include <stdio.h>
@@ -36,7 +36,6 @@
 #include <errno.h>
 
 #include "gui/bookmarks.h"
-#include "gui/setup_druid.h"
 
 #include "main/lists.h"
 #include "main/settings.h"
@@ -50,7 +49,7 @@
  */
 #define GS_DIR ".gnomesword"
 
-#define GS_NET_PERMISSION	"Welcome to GnomeSword.\n\nThere are no Bible modules installed. In order to initialize, GnomeSword needs you to install at least one Bible.\n\nWith your permission, GnomeSword will invoke the Module Manager so that you may install from Crosswire:\n1. Configure remote install.\n2. Connect.\n3. Select a Bible text of your language preference.\n4. Click `install'.\nClose the Module Manager when you are done.\n\nWarning: If you live in a persecuted country, use with care.\n\nMay GnomeSword invoke the Module Manager so that you may install a Bible?"
+#define GS_NET_PERMISSION	_("Welcome to GnomeSword.\n\nThere are no Bible modules installed. In order to initialize, GnomeSword needs you to install at least one Bible.\n\nWith your permission, GnomeSword will invoke the Module Manager so that you may install from Crosswire:\n1. Configure remote install.\n2. Connect.\n3. Select a Bible text of your language preference.\n4. Click `install'.\nClose the Module Manager when you are done.\n\nWarning: If you live in a persecuted country, use with care.\n\nMay GnomeSword invoke the Module Manager so that you may install a Bible?")
 
 /******************************************************************************
  * globals
@@ -96,7 +95,7 @@ int settings_init(int new_configs, int new_bookmarks)
 
 	/* Get home dir */
 	if ((settings.homedir = getenv("HOME")) == NULL) {
-		g_error("$HOME is not set!");
+		g_error(_("$HOME is not set!"));
 		/* if not found in env exit */
 		exit(0);
 	}
@@ -111,10 +110,10 @@ int settings_init(int new_configs, int new_bookmarks)
 		gs_old = g_strdup_printf("%s/.gnomesword-2.0", settings.homedir);
 		if (access(gs_old, F_OK) == 0) {
 			if (rename(gs_old, settings.gSwordDir) == 0)
-				gui_generic_warning("GnomeSword has renamed .gnomesword-2.0 to .gnomesword");
+				gui_generic_warning(_("GnomeSword has renamed .gnomesword-2.0 to .gnomesword"));
 			else {
 				char msg[300];
-				sprintf(msg, "GnomeSword can not rename  .gnomesword-2.0 to .gnomesword:\n%s\n\nGnomeSword cannot continue.",
+				sprintf(msg, _("GnomeSword can not rename  .gnomesword-2.0 to .gnomesword:\n%s\n\nGnomeSword cannot continue."),
 					strerror(errno));
 				gui_generic_warning(msg);
 				/* necessarily giving up. */
@@ -122,7 +121,7 @@ int settings_init(int new_configs, int new_bookmarks)
 			}
 		} else if ((mkdir(settings.gSwordDir, S_IRWXU)) != 0) {
 			char msg[300];
-			sprintf(msg, "GnomeSword can not create  .gnomesword:\n%s\n\nGnomeSword cannot continue.",
+			sprintf(msg, _("GnomeSword can not create  .gnomesword:\n%s\n\nGnomeSword cannot continue."),
 				strerror(errno));
 			gui_generic_warning(msg);
 			/* if we can not create gSwordDir exit */
@@ -142,7 +141,7 @@ int settings_init(int new_configs, int new_bookmarks)
 	sword_dir = g_strdup_printf("%s/%s", settings.homedir, ".sword");
 	if (access(sword_dir, F_OK) == -1) {
 		if ((mkdir(sword_dir, S_IRWXU)) != 0) {
-			printf("can not create  .sword");
+			printf(_("can not create  .sword"));
 		} 
 	}
 	g_free(sword_dir);
@@ -150,7 +149,7 @@ int settings_init(int new_configs, int new_bookmarks)
 	sword_dir = g_strdup_printf("%s/%s", settings.homedir, ".sword/mods.d");
 	if (access(sword_dir, F_OK) == -1) {
 		if ((mkdir(sword_dir, S_IRWXU)) != 0) {
-			printf("can not create  .sword/mods.d");
+			printf(_("can not create  .sword/mods.d"));
 		} 
 	}	
 	g_free(sword_dir);
@@ -158,7 +157,7 @@ int settings_init(int new_configs, int new_bookmarks)
 	sword_dir = g_strdup_printf("%s/%s", settings.homedir,".sword/modules");
 	if (access(sword_dir, F_OK) == -1) {
 		if ((mkdir(sword_dir, S_IRWXU)) != 0) {
-			printf("can not create  .sword/modules");
+			printf(_("can not create  .sword/modules"));
 		} 
 	}
 	g_free(sword_dir);
@@ -188,14 +187,14 @@ int settings_init(int new_configs, int new_bookmarks)
 				main_init_lists();
 				if (settings.havebible == 0) {
 					gui_generic_warning
-					    ("There are still no Bibles installed.\nEvidently, you declined to install any.\n\nWithout any Bible modules to display, GnomeSword cannot proceed, and will now exit.");
+					    (_("There are still no Bibles installed.\nEvidently, you declined to install any.\n\nWithout any Bible modules to display, GnomeSword cannot proceed, and will now exit."));
 					exit(1);
 				} else
 					gui_generic_warning
-					    ("Bible module installation complete.");
+					    (_("Bible module installation complete."));
 			} else {
 				gui_generic_warning
-				    ("Without any Bible modules to display, GnomeSword cannot proceed, and will now exit.");
+				    (_("Without any Bible modules to display, GnomeSword cannot proceed, and will now exit."));
 				exit(1);
 			}
 		}
@@ -211,8 +210,9 @@ int settings_init(int new_configs, int new_bookmarks)
 
 	xml_parse_settings_file(settings.fnconfigure);
 	load_settings_structure();
-	
-	
+
+	gconf_setup();
+
 	return retval;
 }
 
@@ -438,10 +438,22 @@ void load_settings_structure(void)
 	    xml_get_value("HTMLcolors", "versenum");
 	settings.found_color = xml_get_value("HTMLcolors", "found");
 
+	if (buf = xml_get_value("HTMLcolors", "highlight_fg"))
+		settings.highlight_fg = g_strdup(buf);
+	else {
+		xml_add_new_item_to_section("HTMLcolors", "highlight_fg", "#FFFF00");
+		settings.highlight_fg = g_strdup("#FFFF00");
+	}
+	if (buf = xml_get_value("HTMLcolors", "highlight_bg"))
+		settings.highlight_bg = g_strdup(buf);
+	else {
+		xml_add_new_item_to_section("HTMLcolors", "highlight_bg", "#060680");
+		settings.highlight_bg = g_strdup("#060680");
+	}
 
 	buf = xml_get_value("parallel", "strongs");
 	if(buf)
-		settings.strongsint =atoi(buf);
+		settings.strongsint = atoi(buf);
 	
 	buf = xml_get_value("parallel", "morphs");
 	if(buf)
@@ -505,6 +517,21 @@ void load_settings_structure(void)
 		settings.showversenum = 1;
 	}
 
+	if (buf = xml_get_value("misc", "versehighlight"))
+		settings.versehighlight = atoi(buf);
+	else {
+		xml_add_new_item_to_section("misc", "versehighlight", "0");
+		settings.versehighlight = 0;
+	}
+
+	buf = xml_get_value("misc", "doublespace");
+	if (buf)
+		settings.doublespace = atoi(buf);
+	else {
+		xml_add_new_item_to_section("misc", "doublespace", "0");
+		settings.doublespace = 0;
+	}
+
 	settings.usedefault = atoi(xml_get_value("misc", "usedefault"));
 	
 		
@@ -577,8 +604,6 @@ void load_settings_structure(void)
 		xml_add_new_item_to_section("tabs","browsing","1");
 		settings.browsing = 1;
 	}
-	
-	
 
 	/*
 	   settings. = xml_get_value("", "");
@@ -590,39 +615,76 @@ void load_settings_structure(void)
 }
 
 
-
-
-
 /******************************************************************************
  * Name
- *    
+ *    gconf_setup
  *
  * Synopsis
  *   #include "main/settings.h"
  *
- *   	
+ *   void gconf_setup()
  *
  * Description
- *   
+ *   verifies and initializes the GConf subsystem, so that "sword://" and
+ *   similar can be handled by url-comprehending programs such as browsers.
  *
  * Return value
- *   
+ *   void
  */
 
+#define	GS_GCONF_PERMISSION	_("There is currently no program set as your handler for \"sword://\" and similar URLs.  Would you like GnomeSword to install itself as the program to handle these URLs?")
 
+#define	GS_GCONF_SUCCESS	_("GnomeSword has successfully set itself as the handler of sword:// and bible:// URLs.\n\nYou may wish to run the program \"gconf-editor\" to examine keys under /desktop/gnome/url-handlers, if you need to change these.")
 
-/******************************************************************************
- * Name
- *    
- *
- * Synopsis
- *   #include "main/settings.h"
- *
- *   	
- *
- * Description
- *   
- *
- * Return value
- *   
- */
+char *gconf_keys[GS_GCONF_MAX][2] = {
+    { "/desktop/gnome/url-handlers/bible/command",        "gnomesword2 \"%s\"" },
+    { "/desktop/gnome/url-handlers/bible/enabled",        (char *) 1 },
+    { "/desktop/gnome/url-handlers/bible/needs_terminal", (char *) 0 },
+    { "/desktop/gnome/url-handlers/sword/command",        "gnomesword2 \"%s\"" },
+    { "/desktop/gnome/url-handlers/sword/enabled",        (char *) 1 },
+    { "/desktop/gnome/url-handlers/sword/needs_terminal", (char *) 0 }
+};
+
+void gconf_setup()
+{
+	int i;
+	char msg[256];
+	gchar *str;
+	gboolean retval;
+	GConfClient* client = gconf_client_get_default();
+
+	if (client == NULL)
+		return;		/* we're not running under GConf */
+
+	/*
+	 * This is deliberately somewhat simple-minded, at least for now.
+	 * We care about one thing: Is anything set to handle "bible://"?
+	 */
+	if (((str = gconf_client_get_string(client, gconf_keys[0][0],
+					    NULL)) == NULL) &&
+	    gui_yes_no_dialog(GS_GCONF_PERMISSION)) {
+		/*
+		 * Mechanical as can be, one after another.
+		 */
+		for (i = 0; i < GS_GCONF_MAX; ++i) {
+			retval = (((i % 3) == 0)	/* contrived hack */
+				  ? gconf_client_set_string
+					(client,
+					 gconf_keys[i][0],
+					 gconf_keys[i][1],
+					 NULL)
+				  : gconf_client_set_bool
+					(client,
+					 gconf_keys[i][0],
+					 (gconf_keys[i][1] ? TRUE : FALSE),
+					 NULL));
+			if (!retval) {
+				sprintf(msg, _("GnomeSword failed to complete handler init for key #%d:\n%s"),
+					i, gconf_keys[i][0]);
+				gui_generic_warning(msg);
+				return;
+			}
+		}
+		gui_generic_warning(GS_GCONF_SUCCESS);
+	}
+}
