@@ -21,10 +21,19 @@
 
 #ifndef _SETTINGS_H_
 #define _SETTINGS_H_
-
+/*
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 //#include <gnome.h>
-
+#ifdef SUSE_10_2
+#include <glib.h>
+#else
 #include <glib-2.0/glib.h>
+#endif*/
+
+#include <gconf/gconf-client.h>
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -69,6 +78,8 @@ struct _settings {
 		*bible_verse_num_color, /* verse number color */
 		*found_color, /* color to use for search word in results display */
 		*font_color, /*  */
+		*highlight_fg, /* special fg color when highlighting */
+		*highlight_bg, /* special fg color when highlighting */
 		*verse_num_font_size;		
 		
 	int 
@@ -106,6 +117,8 @@ struct _settings {
 	        pinnedtabs, /* all tabs are pinned together, moving in concert */
 	        showversenum, /* display verse numbers in text (default on) */
 	        readaloud, /* pass text through (existing) "festival -server" */
+	        versehighlight, /* do special fg/bg for current verse */
+	        doublespace, /* double-space text (default off) */
 	        parallelpage, /* display parallel page */
 	        autosavepersonalcomments, /* auto save personal notes */
 	        formatpercom, /* use html to format personal notes */
@@ -235,6 +248,9 @@ extern SETTINGS settings;
 
 int settings_init(int new_configs, int new_bookmarks);
 void load_settings_structure(void);
+void gconf_setup(void);
+
+#define	GS_GCONF_MAX	6
 
 #ifdef __cplusplus
 }
