@@ -40,6 +40,7 @@
 #include "main/sidebar.h"
 #include "main/lists.h"
 #include "main/navbar.h"
+#include "main/navbar_book.h"
 #include "main/settings.h"
 #include "main/sword.h"
 //#include "main/tab_struct.h"
@@ -182,6 +183,7 @@ void main_display_verse_list_in_sidebar(gchar * key,
 	    (GTK_TREE_VIEW(sidebar.results_list));
 	if (!gtk_tree_model_get_iter_first(model, &iter))
 		return;
+	gtk_widget_set_sensitive(sidebar.menu_item_save_search,TRUE);
 	path = gtk_tree_model_get_path(model, &iter);
 	gtk_tree_selection_select_path(selection, path);
 
@@ -670,8 +672,8 @@ void main_mod_treeview_button_one(GtkTreeModel * model,
 					      (widgets.
 					       notebook_comm_book), 1);
 		backend->set_module(mod);
-		backend->set_treekey(atoi((key) ? key : (gchar *) "0"));
-		main_display_book(mod, (key) ? key : (gchar *) "0");
+		backend->set_treekey(key ? atoi(key) : 0);
+		main_display_book(mod, (key ? key : (gchar *) "0"));
 		path = gtk_tree_model_get_path(model, &selected);
 		if (!gtk_tree_model_iter_has_child
 		    (GTK_TREE_MODEL(model), &selected)
@@ -684,14 +686,16 @@ void main_mod_treeview_button_one(GtkTreeModel * model,
 		}
 		if (!gtk_tree_model_iter_has_child
 		    (GTK_TREE_MODEL(model), &selected)
-		    && backend->treekey_has_children(atoi(key))) {
+		    && backend->treekey_has_children(key ? atoi(key) : 0)) {
 			add_children_to_tree(model,
-					     selected, mod, atol(key));
+					     selected, mod,
+					     (key ? atol(key) : 0));
 		}
 		gtk_tree_view_expand_row(GTK_TREE_VIEW
 					 (sidebar.module_list), path,
 					 FALSE);
 		gtk_tree_path_free(path);
+		main_setup_navbar_book(mod, (key ? atoi(key) : 0));
 		break;
 	}
 	if (cap)
@@ -729,9 +733,14 @@ static void add_language_folder(GtkTreeModel * model, GtkTreeIter iter,
 	GtkTreeIter parent;
 	GtkTreeIter child_iter;
 	gboolean valid;
+	const gchar *buf;
 
-	if ((!g_ascii_isalnum(language[0])) || (language == NULL))
-		language = N_("Unknown");
+	/* Check language */
+	buf = language;
+	if (!g_utf8_validate(buf,-1,NULL))
+		language = _("Unknown");
+	if (!g_unichar_isalnum(g_utf8_get_char(buf)) || (language == NULL))
+		language = _("Unknown");
 
 	valid = gtk_tree_model_iter_children(model, &iter_iter, &iter);
 	while (valid) {
@@ -781,9 +790,14 @@ static void add_module_to_language_folder(GtkTreeModel * model,
 	GtkTreeIter parent;
 	GtkTreeIter child_iter;
 	gboolean valid;
+	const gchar *buf;
 
-	if ((!g_ascii_isalnum(language[0])) || (language == NULL))
-		language = N_("Unknown");
+	/* Check language */
+	buf = language;
+	if (!g_utf8_validate(buf,-1,NULL))
+		language = _("Unknown");
+	if (!g_unichar_isalnum(g_utf8_get_char(buf)) || (language == NULL))
+		language = _("Unknown");
 
 	valid = gtk_tree_model_iter_children(model, &iter_iter, &iter);
 	while (valid) {
