@@ -48,22 +48,27 @@ extern "C" {
 
 #include <ctype.h>
 #include <time.h>
+#include <dirent.h>
 
 #include "gui/main_window.h"
 #include "gui/font_dialog.h"
 #include "gui/widgets.h"
 #include "gui/commentary.h"
+#include "gui/dialog.h"
 #include "gui/parallel_dialog.h"
 #include "gui/parallel_view.h"
 #include "gui/tabbed_browser.h"
 #include "gui/gnomesword.h"
 #include "gui/sidebar.h"
+//#include "gui/search_sidebar.h"
 #include "gui/utilities.h"
 #include "gui/html.h"
 
 #include "main/display.hh"
 #include "main/lists.h"
 #include "main/navbar.h"
+#include "main/navbar_book.h"
+#include "main/search_sidebar.h"
 #include "main/previewer.h"
 #include "main/settings.h"
 #include "main/sword.h"
@@ -72,6 +77,7 @@ extern "C" {
  
 #include "main/parallel_view.h"
 #include "backend/sword_main.hh"
+#include "backend/gs_stringmgr.h"
 
 extern char *OLD_CODESET;
 using namespace sword; 
@@ -193,8 +199,8 @@ void main_save_note(	const gchar * module_name,
 #endif
 	backend->save_entry(note_str);
 #endif
-	if((!strcmp(settings.CommWindowModule,module_name)) &&  
-				(!strcmp(settings.currentverse, key_str)))
+	if ((!strcmp(settings.CommWindowModule, module_name)) &&  
+	    (!strcmp(settings.currentverse, key_str)))
 		main_display_commentary(module_name, key_str);
 }
 
@@ -225,8 +231,8 @@ void main_delete_note(	const gchar * module_name, const gchar * key_str)
 #endif
 	backend->delete_entry();
 #endif	
-	if((!strcmp(settings.CommWindowModule,module_name)) &&  
-				(!strcmp(settings.currentverse, key_str)))
+	if ((!strcmp(settings.CommWindowModule,module_name)) &&  
+	    (!strcmp(settings.currentverse, key_str)))
 		main_display_commentary(module_name, key_str);
 }
 
@@ -495,7 +501,7 @@ char *main_get_path_to_mods(void)
 {
 	SWMgr *mgr = backend->get_main_mgr();
 	char *path = mgr->prefixPath;
-	if(path)
+	if (path)
 		return g_strdup(path);
 	return NULL;
 }
@@ -524,6 +530,8 @@ void main_init_backend(void)
 	SWMgr mgr;
 	
 	if (!lang) lang="C";
+
+	StringMgr::setSystemStringMgr( new GS_StringMgr() );
 	
 	backend = new BackEnd();
 	backend->init_SWORD(0);
@@ -565,7 +573,7 @@ void main_init_backend(void)
 void main_shutdown_backend(void)
 {
 	free((char*)sword_locale);
-	if(backend) 
+	if (backend) 
 	        delete backend; 
 	backend = NULL;
 		
@@ -699,33 +707,50 @@ void main_dictionary_entry_changed(char * mod_name)
 {	
 	gchar *key = NULL;
 	gchar *key2 = NULL;
-	
-	if(!mod_name) 
+	gsize bytes_read;	
+	gsize bytes_written;	
+	GError **error = NULL;
+
+	if (!mod_name) 
 		return;
-	if(strcmp(settings.DictWindowModule,mod_name)) {
-		xml_set_value("GnomeSword", "modules", "dict",
-					mod_name);
-		settings.DictWindowModule = xml_get_value(
-					"modules", "dict");
+	if (strcmp(settings.DictWindowModule, mod_name)) {
+		xml_set_value("GnomeSword", "modules", "dict", mod_name);
+		settings.DictWindowModule = xml_get_value("modules", "dict");
 	}	
 	
 	key = g_strdup((gchar*)gtk_entry_get_text(GTK_ENTRY(widgets.entry_dict)));
 	
-	key2 = g_utf8_strup(key,strlen(key));
-	
+//	key2 = g_utf8_strup(key, strlen(key));
+	key2 = g_convert(  key,	
+			     -1,	
+			     UTF_8,	
+			     OLD_CODESET,	
+			     &bytes_read,	
+			     &bytes_written,
+			     error);		
+
 	backend->set_module_key(mod_name, key2);
 	g_free(key2);
 	g_free(key);
 	key = backend->get_module_key();
-	
+
+	key2 = g_convert(  key,	
+			     -1,	
+			     OLD_CODESET,	
+			     UTF_8,	
+			     &bytes_read,	
+			     &bytes_written,
+			     error);	
+		
 	xml_set_value("GnomeSword", "keys", "dictionary", key);
 	settings.dictkey = xml_get_value("keys", "dictionary");
 	
 	backend->set_module_key(mod_name, key);
 	backend->display_mod->Display();
 	
-	gtk_entry_set_text(GTK_ENTRY(widgets.entry_dict), key);
+	gtk_entry_set_text(GTK_ENTRY(widgets.entry_dict), key2);
 	g_free(key);
+	g_free(key2);
 } 
 
 
@@ -775,15 +800,17 @@ GtkWidget *main_dictionary_drop_down_new(char * mod_name, char * old_key)
 	gchar *key = NULL;
 	gchar *key2 = NULL;
 	gint height;
-        gsize bytes_written;
 	GtkWidget *menu;
 	GtkWidget * item;
+	gsize bytes_read;
+	gsize bytes_written;
+	GError **error = NULL;
 	
 	menu = gtk_menu_new();
 	
-	if(!settings.havedict || !mod_name)
+	if (!settings.havedict || !mod_name)
 		return NULL;
-	if(strcmp(settings.DictWindowModule,mod_name)) {
+	if (strcmp(settings.DictWindowModule,mod_name)) {
 		xml_set_value("GnomeSword", "modules", "dict",
 					mod_name);
 		settings.DictWindowModule = xml_get_value(
@@ -794,7 +821,15 @@ GtkWidget *main_dictionary_drop_down_new(char * mod_name, char * old_key)
 #ifdef DEBUG
 	g_message("\nold_key: %s\nkey: %s",old_key,key);
 #endif	
-	key2 = g_utf8_strup(key,strlen(key));
+//	key2 = g_utf8_strup(key,strlen(key));
+	key2 = g_convert(  key,	
+			     -1,	
+			     UTF_8,	
+			     OLD_CODESET,	
+			     &bytes_read,	
+			     &bytes_written,
+			     error);
+
 	
 	backend->set_module_key(mod_name, key2);
 	g_free(key2);
@@ -874,12 +909,12 @@ void main_dictionary_button_clicked(gint direction)
 {	
 	gchar *key = NULL;
 	
-	if(!settings.havedict || !settings.DictWindowModule)
+	if (!settings.havedict || !settings.DictWindowModule)
 		return;
 		
 	backend->set_module_key(settings.DictWindowModule, 
 				settings.dictkey);
-	if(direction == 0)
+	if (direction == 0)
 		(*backend->display_mod)--;
 	else
 		(*backend->display_mod)++;
@@ -891,67 +926,71 @@ void main_dictionary_button_clicked(gint direction)
 
 void main_display_book(const char * mod_name, char * key)
 {
-	gboolean use_offset = FALSE;
-	if(!settings.havebook || !mod_name)
+#ifdef DEBUG
+	g_message("main_display_book\nmod_name: %s\nkey: %s", mod_name, key);
+#endif
+
+	if (!settings.havebook || !mod_name)
 		return;
-	if(!backend->is_module(mod_name))
+	if (!backend->is_module(mod_name))
 		return;
-	if(!settings.book_mod)
+	if (!settings.book_mod)
 		settings.book_mod = (char*)mod_name;
-	
-	
-	settings.whichwindow = BOOK_WINDOW;
-	if(key == NULL) key = "0";
-	if(isalpha(key[0])) {
-		xml_set_value("GnomeSword", "keys", "book", key);
-		settings.book_key = xml_get_value( "keys", "book");
-		use_offset = FALSE;
-	} else {
-		xml_set_value("GnomeSword", "keys", "offset", key);
-		settings.book_offset = atol(xml_get_value( "keys", "offset"));
-		use_offset = TRUE;
-	}
-	
-	if(strcmp(settings.book_mod,mod_name)) {
+
+	if (strcmp(settings.book_mod, mod_name)) {
 		xml_set_value("GnomeSword", "modules", "book", mod_name);
-		settings.book_mod = xml_get_value( "modules", "book");
+		settings.book_mod = xml_get_value("modules", "book");
 	}
-	if(use_offset) {
+	
+	if (key == NULL)
+		key = "0";
+
+	if (!isdigit(key[0])) {
+		xml_set_value("GnomeSword", "keys", "book", key);
+		settings.book_key = xml_get_value("keys", "book");
+
+		backend->set_module(mod_name);
+		backend->set_treekey(0);
+		settings.book_offset = backend->treekey_set_key(key);
+	} else {
+		settings.book_offset = atol(key);
+		if(settings.book_offset < 4)
+			settings.book_offset = 4;
+		xml_set_value("GnomeSword", "keys", "offset", key);
+
 		backend->set_module(mod_name);	
 		backend->set_treekey(settings.book_offset);
-	} else {
-		backend->set_module_key(mod_name, key);
 	}
-	backend->display_mod->Display();
 	
-	if(settings.browsing)
+	backend->display_mod->Display();
+	main_setup_navbar_book(settings.book_mod, settings.book_offset);
+	if (settings.browsing)
 		gui_update_tab_struct(NULL,
 				      NULL,
 				      NULL,
 				      mod_name,
 				      NULL,
-				      key?key:NULL,
+				      key,
 				      FALSE);
-
 }
 
 void main_display_commentary(const char * mod_name, const char * key)
 {	
-	if(!settings.havecomm || !settings.comm_showing)
+	if (!settings.havecomm || !settings.comm_showing)
 		return;
 	
-	if(!mod_name)
+	if (!mod_name)
 		mod_name = xml_get_value("modules", "comm");
 	
-	if(!mod_name || !backend->is_module(mod_name))
+	if (!mod_name || !backend->is_module(mod_name))
 		return;
-	if(!settings.CommWindowModule)
+	if (!settings.CommWindowModule)
 		settings.CommWindowModule = (char*)mod_name;
 	
 	settings.comm_showing = TRUE;
 	settings.whichwindow = COMMENTARY_WINDOW;
 						
-	if(strcmp(settings.CommWindowModule,mod_name)) {
+	if (strcmp(settings.CommWindowModule,mod_name)) {
 		xml_set_value("GnomeSword", "modules", "comm", mod_name);
 		settings.CommWindowModule = xml_get_value( "modules", "comm");
 	}
@@ -959,7 +998,7 @@ void main_display_commentary(const char * mod_name, const char * key)
 	backend->set_module_key(mod_name, key);
 	backend->display_mod->Display();
 	
-	if(settings.browsing)
+	if (settings.browsing)
 		gui_update_tab_struct(NULL,
 				      mod_name,
 				      NULL,
@@ -973,34 +1012,34 @@ void main_display_dictionary(char * mod_name, char * key)
 {
 	const gchar *old_key;
 #ifdef DEBUG
-	g_message("main_display_dictionary\nmod_name: %s\nkey: %s",mod_name,key);
+	g_message("main_display_dictionary\nmod_name: %s\nkey: %s", mod_name, key);
 #endif
-	if(!settings.havedict || !mod_name)
+
+	if (!settings.havedict || !mod_name)
 		return;
-	if(!backend->is_module(mod_name))
+	if (!backend->is_module(mod_name))
 		return;
-	if(!settings.DictWindowModule)
+	if (!settings.DictWindowModule)
 		settings.DictWindowModule = (char*)mod_name;
-	if(strcmp(settings.DictWindowModule,mod_name)) {
-		xml_set_value("GnomeSword", "modules", "dict",
-					mod_name);
-		settings.DictWindowModule = xml_get_value(
-					"modules", "dict");
+
+	if (strcmp(settings.DictWindowModule, mod_name)) {
+		xml_set_value("GnomeSword", "modules", "dict", mod_name);
+		settings.DictWindowModule = xml_get_value("modules", "dict");
 	}
-	//gtk_label_set_text (GTK_LABEL(widgets.label_dict),mod_name);
 	
-	if(key == NULL)
+	if (key == NULL)
 		key = "Grace";
-	
+	// old_key is uppercase
+	key = g_utf8_strup(key, -1);
 	old_key = gtk_entry_get_text(GTK_ENTRY(widgets.entry_dict));
-	if(!strcmp(old_key, key))
+	if (!strcmp(old_key, key))
 		main_dictionary_entry_changed(settings.DictWindowModule);
 	else {
 		gtk_entry_set_text(GTK_ENTRY(widgets.entry_dict), key);
 		gtk_widget_activate(widgets.entry_dict);
 	}
 	
-	if(settings.browsing)
+	if (settings.browsing)
 		gui_update_tab_struct(NULL,
 				      NULL,
 				      mod_name,
@@ -1058,48 +1097,51 @@ void main_display_bible(const char * mod_name, const char * key)
 	/* keeps us out of a crash causing loop */
 	g_signal_handler_block(adjustment, scroll_adj_signal);
 	
-	if(!mod_name)
+	if (!mod_name)
 		mod_name = xml_get_value("modules", "bible");	
 	
 	
-	if(!settings.havebible || !mod_name)
+	if (!settings.havebible || !mod_name)
 		return;
-	if(!backend->is_module(mod_name))
+	if (!backend->is_module(mod_name))
 		return;
 	
-	file = g_strdup_printf("%s/modops.conf", settings.gSwordDir);
-	if(!settings.MainWindowModule)
+	if (!settings.MainWindowModule)
 		settings.MainWindowModule = (char*)mod_name;
 	
-	if(strcmp(settings.currentverse, key)) {
+	if (strcmp(settings.currentverse, key)) {
 		xml_set_value("GnomeSword", "keys", "verse",
 					key);
 		settings.currentverse = xml_get_value(
 					"keys", "verse");
 	}
 	
-	if(strcmp(settings.MainWindowModule, mod_name)) {
+	if (strcmp(settings.MainWindowModule, mod_name)) {
 		xml_set_value("GnomeSword", "modules", "bible",
 					mod_name);
 		settings.MainWindowModule = xml_get_value(
 					"modules", "bible");
-		if(navbar_main.module_name) 
+		if (navbar_main.module_name) 
 			g_free(navbar_main.module_name);
 		navbar_main.module_name = g_strdup(settings.MainWindowModule);
-		if(navbar_main.key)
+		if (navbar_main.key)
 			g_free(navbar_main.key);
 		navbar_main.key = g_strdup(settings.currentverse);
 		main_navbar_fill_book_combo(navbar_main);
+		main_search_sidebar_fill_bounds_combos();
 	}
 	
 	settings.whichwindow = MAIN_TEXT_WINDOW;
 	gui_change_window_title(settings.MainWindowModule);
 	
+	file = g_strdup_printf("%s/modops.conf", settings.gSwordDir);
 	style = get_conf_file_item(file, mod_name, "style");
-	if((style) && strcmp(style,"verse"))
+	if ((style) && strcmp(style,"verse"))
 		settings.versestyle = FALSE;
 	else	
 		settings.versestyle = TRUE;
+	g_free(style);
+	g_free(file);
 	
 	style_display = FALSE;
 	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM
@@ -1107,12 +1149,12 @@ void main_display_bible(const char * mod_name, const char * key)
 				       settings.versestyle);
 	style_display = TRUE;
 	
-	if(backend->module_has_testament(mod_name,
+	if (backend->module_has_testament(mod_name,
 				backend->get_key_testament(key))) {
 			backend->set_module_key(mod_name, key);
 			backend->display_mod->Display();
 	} else {
-		if(backend->get_key_testament(key) == 1)
+		if (backend->get_key_testament(key) == 1)
 			val_key = main_update_nav_controls("Matthew 1:1");
 		else
 			val_key = main_update_nav_controls("Genesis 1:1");
@@ -1125,7 +1167,7 @@ void main_display_bible(const char * mod_name, const char * key)
 #ifdef DEBUG 
 	g_print("mod_name = %s\n",mod_name);	
 #endif
-	if(settings.browsing) {
+	if (settings.browsing) {
 		gui_update_tab_struct(mod_name,
 				      NULL,
 				      NULL,
@@ -1172,6 +1214,22 @@ void main_display_devotional(void)
 	struct tm *loctime;
 	gchar *text;
 
+	/*
+	 * This makes sense only if you've installed & defined one.
+	 */
+	if (settings.devotionalmod == NULL) {
+		GList *glist = get_list(DEVOTION_LIST);
+
+		if (g_list_length(glist) != 0) {
+			xml_set_value("GnomeSword", "modules", "devotional",
+				      (char*)glist->data );
+			settings.devotionalmod = xml_get_value("modules",
+							       "devotional");
+		} else {
+			gui_generic_warning(_("Daily devotional was requested, but there are none installed."));
+		}
+	}
+
 	/*
 	 * Get the current time.
 	 */
@@ -1187,7 +1245,9 @@ void main_display_devotional(void)
 	 */
 	strftime(buf, 80, "%m.%d", loctime);
 	
+	
 	text = backend->get_render_text(settings.devotionalmod, buf);
+//	g_message("modname: %s\nloctime: %s\ntext: %s",settings.devotionalmod, buf, text);
 	if (text) {
 		main_entry_display(sidebar.html_viewer_widget,
 			      settings.devotionalmod, text, buf, TRUE);
@@ -1206,10 +1266,10 @@ void main_setup_displays(void)
 	backend->bookDisplay = new GTKMozEntryDisp(widgets.html_book,backend);
 	backend->dictDisplay = new GTKMozEntryDisp(widgets.html_dict,backend);
 
-#else*/
+#else
 #ifndef USE_GTKMOZEMBED
-	backend->RTOLDisplay = new GTKTextviewChapDisp(widgets.textview,backend);
-#endif
+	backend->RTOLDisplay =  new GTKChapDisp(widgets.html_text,backend);    //new GTKTextviewChapDisp(widgets.textview,backend);
+#endif*/
 	backend->textDisplay = new GTKChapDisp(widgets.html_text,backend);
 	backend->commDisplay = new GTKEntryDisp(widgets.html_comm,backend);
 	backend->bookDisplay = new GTKEntryDisp(widgets.html_book,backend);
@@ -1287,15 +1347,54 @@ char *main_get_mod_about_info(char * mod_name)
 	return backend->get_config_entry(mod_name, "About");
 }
 
-
-const char *main_get_mod_config_entry(const char * module_name, const char * entry)
+char *main_get_mod_config_entry(const char * module_name,
+				      const char * entry)
 {
 	return backend->get_config_entry((char*)module_name, (char*)entry);
 }
+
+char *main_get_mod_config_file(const char * module_name,
+				     const char * moddir)
+{
+#ifdef  SWORD_SHOULD_HAVE_A_WAY_TO_GET_A_CONF_FILENAME_FROM_A_MODNAME
+	return backend->get_config_file((char*)module_name, (char*)moddir);
+#else
+	DIR *dir;
+	struct dirent *ent;
+	SWBuf name;
+
+	name =  moddir;
+	name += "/mods.d";
+	if (dir = opendir(name)) {
+		rewinddir(dir);
+		while (ent = readdir(dir)) {
+			if ((strcmp(ent->d_name, ".")) &&
+			    (strcmp(ent->d_name, ".."))) {
+				name =  moddir;
+				name += "/mods.d/";
+				name += ent->d_name;
+				SWConfig *config = new SWConfig(name.c_str());
+				if (config->Sections.find(module_name) !=
+				    config->Sections.end()) {
+					char *ret_name = g_strdup(ent->d_name);
+					closedir(dir);
+					delete config;
+					return ret_name;
+				}
+				else
+					delete config;
+			}
+		}
+		closedir(dir);
+	}
+	return NULL;
+#endif
+}
+
 int main_is_mod_rtol(const char * module_name)
 {
 	char *direction = backend->get_config_entry((char*)module_name, "Direction");
-	if(direction && !strcmp(direction, "RtoL"))
+	if (direction && !strcmp(direction, "RtoL"))
 		return TRUE;
 	return FALSE;
 }
@@ -1319,7 +1418,7 @@ int main_is_mod_rtol(const char * module_name)
 int main_has_cipher_tag(char *mod_name)
 {
 	gchar *tmpbuf = backend->get_config_entry(mod_name, "CipherKey");
-	if(tmpbuf) {
+	if (tmpbuf) {
 		return true;
 	}
 	return false;
@@ -1390,6 +1489,29 @@ char *main_get_rendered_text(char *module_name, char *key)
 {
 	return backend->get_render_text(module_name, key);
 }
+
+
+/******************************************************************************
+ * Name
+ *   main_get_raw_text
+ *
+ * Synopsis
+ *   #include "main/sword.h"
+ *
+ *   char *main_get_raw_text(char *module_name, char *key)	
+ *
+ * Description
+ *   
+ *
+ * Return value
+ *   char *
+ */
+
+char *main_get_raw_text(char *module_name, char *key)
+{
+	return backend->get_raw_text(module_name, key);
+}
+
 /******************************************************************************
  * Name
  *  main_get_mod_type
