@@ -27,7 +27,7 @@ extern "C" {
 #endif
 #include <gnome.h>
 #include <glib/gi18n.h>
-#include <glib-2.0/glib.h>
+//#include <glib-2.0/glib.h>
 	
 #include "main/configs.h"	
 	
@@ -96,12 +96,15 @@ const char *main_get_module_language(const char *module_name);
 int main_check_for_global_option(char * mod_name, char * option);
 int main_has_cipher_tag(char *mod_name);
 int main_is_module(char * mod_name);
-const char *main_get_mod_config_entry(const char * module_name, 
-					const char * entry);
+char *main_get_mod_config_entry(const char * module_name,
+				      const char * entry);
+char *main_get_mod_config_file(const char * module_name,
+			       const char * moddir);
 char *main_get_mod_about_info(char * mod_name);
 char *main_get_striptext(char *module_name, char *key);
 char *main_get_striptext_from_string(char *module_name, char *string);
 char *main_get_rendered_text(char *module_name, char *key);
+char *main_get_raw_text(char *module_name, char *key);
 int main_get_mod_type(char * mod_name);
 char *main_get_module_description(char * module_name);
 char *main_get_treekey_local_name(unsigned long offset);
